from box_sdk_gen.schemas.ai_agent_info import *

from box_sdk_gen.schemas.ai_response import *

from box_sdk_gen.schemas.ai_agent_reference import *

from box_sdk_gen.schemas.ai_citation import *

from box_sdk_gen.schemas.ai_response_full import *

from box_sdk_gen.schemas.ai_dialogue_history import *

from box_sdk_gen.schemas.ai_extract_structured_response import *

from box_sdk_gen.schemas.ai_item_base import *

from box_sdk_gen.schemas.ai_item_ask import *

from box_sdk_gen.schemas.ai_llm_endpoint_params_aws import *

from box_sdk_gen.schemas.ai_llm_endpoint_params_google import *

from box_sdk_gen.schemas.ai_llm_endpoint_params_ibm import *

from box_sdk_gen.schemas.ai_llm_endpoint_params_open_ai import *

from box_sdk_gen.schemas.ai_llm_endpoint_params import *

from box_sdk_gen.schemas.ai_agent_spreadsheet_tool import *

from box_sdk_gen.schemas.ai_studio_agent_spreadsheet_tool import *

from box_sdk_gen.schemas.ai_studio_agent_spreadsheet_tool_response import *

from box_sdk_gen.schemas.ai_agent_basic_text_tool_base import *

from box_sdk_gen.schemas.ai_agent_basic_text_tool_text_gen import *

from box_sdk_gen.schemas.ai_agent_long_text_tool_text_gen import *

from box_sdk_gen.schemas.ai_agent_basic_gen_tool import *

from box_sdk_gen.schemas.ai_studio_agent_basic_gen_tool import *

from box_sdk_gen.schemas.ai_studio_agent_text_gen import *

from box_sdk_gen.schemas.ai_studio_agent_basic_gen_tool_response import *

from box_sdk_gen.schemas.ai_studio_agent_text_gen_response import *

from box_sdk_gen.schemas.ai_agent_text_gen import *

from box_sdk_gen.schemas.ai_text_gen_agent import *

from box_sdk_gen.schemas.ai_text_gen import *

from box_sdk_gen.schemas.ai_agent_basic_text_tool import *

from box_sdk_gen.schemas.ai_studio_agent_basic_text_tool import *

from box_sdk_gen.schemas.ai_studio_agent_basic_text_tool_response import *

from box_sdk_gen.schemas.ai_agent_long_text_tool import *

from box_sdk_gen.schemas.ai_studio_agent_long_text_tool import *

from box_sdk_gen.schemas.ai_studio_agent_long_text_tool_response import *

from box_sdk_gen.schemas.ai_studio_agent_extract_response import *

from box_sdk_gen.schemas.ai_studio_agent_ask_response import *

from box_sdk_gen.schemas.ai_studio_agent_extract import *

from box_sdk_gen.schemas.ai_studio_agent_ask import *

from box_sdk_gen.schemas.ai_agent_extract_structured import *

from box_sdk_gen.schemas.ai_extract_structured_agent import *

from box_sdk_gen.schemas.ai_extract_structured import *

from box_sdk_gen.schemas.ai_agent_extract import *

from box_sdk_gen.schemas.ai_extract_agent import *

from box_sdk_gen.schemas.ai_extract import *

from box_sdk_gen.schemas.ai_agent_ask import *

from box_sdk_gen.schemas.ai_ask_agent import *

from box_sdk_gen.schemas.ai_ask import *

from box_sdk_gen.schemas.ai_agent import *

from box_sdk_gen.schemas.app_item import *

from box_sdk_gen.schemas.classification import *

from box_sdk_gen.schemas.classification_template import *

from box_sdk_gen.schemas.client_error import *

from box_sdk_gen.schemas.collaboration_allowlist_entry import *

from box_sdk_gen.schemas.collaboration_allowlist_entries import *

from box_sdk_gen.schemas.collaborator_variable import *

from box_sdk_gen.schemas.collection import *

from box_sdk_gen.schemas.collections import *

from box_sdk_gen.schemas.comment_base import *

from box_sdk_gen.schemas.completion_rule_variable import *

from box_sdk_gen.schemas.email_alias import *

from box_sdk_gen.schemas.email_aliases import *

from box_sdk_gen.schemas.enterprise_base import *

from box_sdk_gen.schemas.file_base import *

from box_sdk_gen.schemas.file_request_update_request import *

from box_sdk_gen.schemas.file_request_copy_request import *

from box_sdk_gen.schemas.file_version_base import *

from box_sdk_gen.schemas.file_version_mini import *

from box_sdk_gen.schemas.file_mini import *

from box_sdk_gen.schemas.files_under_retention import *

from box_sdk_gen.schemas.files_on_hold import *

from box_sdk_gen.schemas.file_conflict import *

from box_sdk_gen.schemas.conflict_error import *

from box_sdk_gen.schemas.folder_base import *

from box_sdk_gen.schemas.folder_mini import *

from box_sdk_gen.schemas.resource import *

from box_sdk_gen.schemas.resource_scope import *

from box_sdk_gen.schemas.access_token import *

from box_sdk_gen.schemas.folder_reference import *

from box_sdk_gen.schemas.group_base import *

from box_sdk_gen.schemas.group_mini import *

from box_sdk_gen.schemas.group import *

from box_sdk_gen.schemas.group_full import *

from box_sdk_gen.schemas.groups import *

from box_sdk_gen.schemas.integration_mapping_base import *

from box_sdk_gen.schemas.integration_mapping_box_item_slack import *

from box_sdk_gen.schemas.integration_mapping_partner_item_slack import *

from box_sdk_gen.schemas.integration_mapping_partner_item_teams import *

from box_sdk_gen.schemas.integration_mapping_teams import *

from box_sdk_gen.schemas.integration_mappings_teams import *

from box_sdk_gen.schemas.integration_mapping_partner_item_teams_create_request import *

from box_sdk_gen.schemas.integration_mapping_teams_create_request import *

from box_sdk_gen.schemas.integration_mapping_slack_options import *

from box_sdk_gen.schemas.integration_mapping_slack_create_request import *

from box_sdk_gen.schemas.keyword_skill_card import *

from box_sdk_gen.schemas.legal_hold_policy_mini import *

from box_sdk_gen.schemas.legal_hold_policy_assignment_base import *

from box_sdk_gen.schemas.metadata_base import *

from box_sdk_gen.schemas.metadata import *

from box_sdk_gen.schemas.metadatas import *

from box_sdk_gen.schemas.metadata_full import *

from box_sdk_gen.schemas.metadata_cascade_policy import *

from box_sdk_gen.schemas.metadata_cascade_policies import *

from box_sdk_gen.schemas.metadata_error import *

from box_sdk_gen.schemas.metadata_field_filter_date_range import *

from box_sdk_gen.schemas.metadata_field_filter_float_range import *

from box_sdk_gen.schemas.metadata_filter_value import *

from box_sdk_gen.schemas.metadata_filter import *

from box_sdk_gen.schemas.metadata_instance_value import *

from box_sdk_gen.schemas.metadata_query import *

from box_sdk_gen.schemas.metadata_taxonomy_ancestor import *

from box_sdk_gen.schemas.metadata_taxonomy_node import *

from box_sdk_gen.schemas.metadata_taxonomy_nodes import *

from box_sdk_gen.schemas.metadata_taxonomy_level import *

from box_sdk_gen.schemas.metadata_taxonomy_levels import *

from box_sdk_gen.schemas.metadata_taxonomy import *

from box_sdk_gen.schemas.metadata_taxonomies import *

from box_sdk_gen.schemas.metadata_template import *

from box_sdk_gen.schemas.metadata_templates import *

from box_sdk_gen.schemas.o_auth_2_error import *

from box_sdk_gen.schemas.post_o_auth_2_revoke import *

from box_sdk_gen.schemas.post_o_auth_2_token import *

from box_sdk_gen.schemas.post_o_auth_2_token_refresh_access_token import *

from box_sdk_gen.schemas.realtime_server import *

from box_sdk_gen.schemas.realtime_servers import *

from box_sdk_gen.schemas.retention_policy_base import *

from box_sdk_gen.schemas.retention_policy_mini import *

from box_sdk_gen.schemas.file_version_retention import *

from box_sdk_gen.schemas.file_version_retentions import *

from box_sdk_gen.schemas.role_variable import *

from box_sdk_gen.schemas.outcome import *

from box_sdk_gen.schemas.session_termination_message import *

from box_sdk_gen.schemas.shield_information_barrier_base import *

from box_sdk_gen.schemas.shield_information_barrier_reference import *

from box_sdk_gen.schemas.shield_information_barrier_report_base import *

from box_sdk_gen.schemas.shield_information_barrier_report_details import *

from box_sdk_gen.schemas.shield_information_barrier_segment_member_base import *

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_base import *

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_mini import *

from box_sdk_gen.schemas.sign_request_cancel_request import *

from box_sdk_gen.schemas.sign_request_create_signer import *

from box_sdk_gen.schemas.sign_request_prefill_tag import *

from box_sdk_gen.schemas.sign_request_base import *

from box_sdk_gen.schemas.sign_request_create_request import *

from box_sdk_gen.schemas.sign_request_signer_attachment import *

from box_sdk_gen.schemas.sign_request_signer_input_custom_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_date_asia_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_date_eu_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_date_iso_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_date_us_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_email_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_number_with_comma_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_number_with_period_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_ssn_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_zip_4_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_zip_validation import *

from box_sdk_gen.schemas.sign_request_signer_input_validation import *

from box_sdk_gen.schemas.template_signer_input import *

from box_sdk_gen.schemas.template_signer import *

from box_sdk_gen.schemas.sign_template import *

from box_sdk_gen.schemas.sign_templates import *

from box_sdk_gen.schemas.sign_request_signer_input import *

from box_sdk_gen.schemas.sign_request_signer import *

from box_sdk_gen.schemas.sign_request import *

from box_sdk_gen.schemas.sign_requests import *

from box_sdk_gen.schemas.status_skill_card import *

from box_sdk_gen.schemas.storage_policy_mini import *

from box_sdk_gen.schemas.storage_policy_assignment import *

from box_sdk_gen.schemas.storage_policy_assignments import *

from box_sdk_gen.schemas.storage_policy import *

from box_sdk_gen.schemas.storage_policies import *

from box_sdk_gen.schemas.terms_of_service_base import *

from box_sdk_gen.schemas.terms_of_service import *

from box_sdk_gen.schemas.terms_of_services import *

from box_sdk_gen.schemas.timeline_skill_card import *

from box_sdk_gen.schemas.tracking_code import *

from box_sdk_gen.schemas.transcript_skill_card import *

from box_sdk_gen.schemas.skill_card import *

from box_sdk_gen.schemas.skill_cards_metadata import *

from box_sdk_gen.schemas.upload_part_mini import *

from box_sdk_gen.schemas.upload_part import *

from box_sdk_gen.schemas.upload_parts import *

from box_sdk_gen.schemas.uploaded_part import *

from box_sdk_gen.schemas.upload_session import *

from box_sdk_gen.schemas.upload_url import *

from box_sdk_gen.schemas.user_base import *

from box_sdk_gen.schemas.user_integration_mappings import *

from box_sdk_gen.schemas.integration_mapping import *

from box_sdk_gen.schemas.integration_mappings import *

from box_sdk_gen.schemas.user_mini import *

from box_sdk_gen.schemas.user import *

from box_sdk_gen.schemas.user_full import *

from box_sdk_gen.schemas.users import *

from box_sdk_gen.schemas.trash_web_link_restored import *

from box_sdk_gen.schemas.trash_web_link import *

from box_sdk_gen.schemas.trash_folder_restored import *

from box_sdk_gen.schemas.trash_folder import *

from box_sdk_gen.schemas.trash_file_restored import *

from box_sdk_gen.schemas.trash_file import *

from box_sdk_gen.schemas.terms_of_service_user_status import *

from box_sdk_gen.schemas.terms_of_service_user_statuses import *

from box_sdk_gen.schemas.task_assignment import *

from box_sdk_gen.schemas.task_assignments import *

from box_sdk_gen.schemas.task import *

from box_sdk_gen.schemas.tasks import *

from box_sdk_gen.schemas.retention_policy_assignment import *

from box_sdk_gen.schemas.retention_policy_assignments import *

from box_sdk_gen.schemas.retention_policy import *

from box_sdk_gen.schemas.retention_policies import *

from box_sdk_gen.schemas.legal_hold_policy import *

from box_sdk_gen.schemas.legal_hold_policies import *

from box_sdk_gen.schemas.invite import *

from box_sdk_gen.schemas.group_membership import *

from box_sdk_gen.schemas.group_memberships import *

from box_sdk_gen.schemas.file_version import *

from box_sdk_gen.schemas.file_version_full import *

from box_sdk_gen.schemas.file_versions import *

from box_sdk_gen.schemas.file_request import *

from box_sdk_gen.schemas.file import *

from box_sdk_gen.schemas.file_full import *

from box_sdk_gen.schemas.files import *

from box_sdk_gen.schemas.event_source import *

from box_sdk_gen.schemas.device_pinner import *

from box_sdk_gen.schemas.device_pinners import *

from box_sdk_gen.schemas.comment import *

from box_sdk_gen.schemas.comment_full import *

from box_sdk_gen.schemas.comments import *

from box_sdk_gen.schemas.collaboration_allowlist_exempt_target import *

from box_sdk_gen.schemas.collaboration_allowlist_exempt_targets import *

from box_sdk_gen.schemas.app_item_event_source import *

from box_sdk_gen.schemas.user_collaborations import *

from box_sdk_gen.schemas.collaboration_access_grantee import *

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction import *

from box_sdk_gen.schemas.shield_information_barrier_segment_restrictions import *

from box_sdk_gen.schemas.shield_information_barrier_segment_member_mini import *

from box_sdk_gen.schemas.shield_information_barrier_segment_member import *

from box_sdk_gen.schemas.shield_information_barrier_segment_members import *

from box_sdk_gen.schemas.shield_information_barrier_segment import *

from box_sdk_gen.schemas.shield_information_barrier_segments import *

from box_sdk_gen.schemas.shield_information_barrier_report import *

from box_sdk_gen.schemas.shield_information_barrier_reports import *

from box_sdk_gen.schemas.shield_information_barrier import *

from box_sdk_gen.schemas.shield_information_barriers import *

from box_sdk_gen.schemas.folder_lock import *

from box_sdk_gen.schemas.folder_locks import *

from box_sdk_gen.schemas.ai_agent_allowed_entity import *

from box_sdk_gen.schemas.create_ai_agent import *

from box_sdk_gen.schemas.ai_single_agent_response import *

from box_sdk_gen.schemas.ai_single_agent_response_full import *

from box_sdk_gen.schemas.ai_multiple_agent_response import *

from box_sdk_gen.schemas.user_avatar import *

from box_sdk_gen.schemas.watermark import *

from box_sdk_gen.schemas.webhook_mini import *

from box_sdk_gen.schemas.webhooks import *

from box_sdk_gen.schemas.webhook import *

from box_sdk_gen.schemas.web_link_base import *

from box_sdk_gen.schemas.web_link_mini import *

from box_sdk_gen.schemas.web_link import *

from box_sdk_gen.schemas.item import *

from box_sdk_gen.schemas.items_offset_paginated import *

from box_sdk_gen.schemas.items import *

from box_sdk_gen.schemas.folder import *

from box_sdk_gen.schemas.legal_hold_policy_assigned_item import *

from box_sdk_gen.schemas.legal_hold_policy_assignment import *

from box_sdk_gen.schemas.legal_hold_policy_assignments import *

from box_sdk_gen.schemas.file_version_legal_hold import *

from box_sdk_gen.schemas.file_version_legal_holds import *

from box_sdk_gen.schemas.folder_full import *

from box_sdk_gen.schemas.search_result_with_shared_link_item import *

from box_sdk_gen.schemas.search_result_with_shared_link import *

from box_sdk_gen.schemas.search_results_with_shared_links import *

from box_sdk_gen.schemas.search_result_item import *

from box_sdk_gen.schemas.search_results import *

from box_sdk_gen.schemas.search_results_response import *

from box_sdk_gen.schemas.recent_item_resource import *

from box_sdk_gen.schemas.recent_item import *

from box_sdk_gen.schemas.recent_items import *

from box_sdk_gen.schemas.metadata_query_result_item import *

from box_sdk_gen.schemas.metadata_query_results import *

from box_sdk_gen.schemas.event_source_resource import *

from box_sdk_gen.schemas.event import *

from box_sdk_gen.schemas.events import *

from box_sdk_gen.schemas.collaboration_item import *

from box_sdk_gen.schemas.collaboration import *

from box_sdk_gen.schemas.collaborations_offset_paginated import *

from box_sdk_gen.schemas.collaborations import *

from box_sdk_gen.schemas.app_item_associated_item import *

from box_sdk_gen.schemas.app_item_association import *

from box_sdk_gen.schemas.app_item_associations import *

from box_sdk_gen.schemas.workflow_mini import *

from box_sdk_gen.schemas.workflow import *

from box_sdk_gen.schemas.workflows import *

from box_sdk_gen.schemas.zip_download import *

from box_sdk_gen.schemas.zip_download_request import *

from box_sdk_gen.schemas.zip_download_status import *

from box_sdk_gen.schemas.v2025_r0 import *



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class MetadataFieldFilterDateRange(BaseObject):
    def __init__(
        self, *, lt: Optional[DateTime] = None, gt: Optional[DateTime] = None, **kwargs
    ):
        """
                :param lt: Specifies the (inclusive) upper bound for the metadata field
        value. The value of a field must be lower than (`lt`) or
        equal to this value for the search query to match this
        template., defaults to None
                :type lt: Optional[DateTime], optional
                :param gt: Specifies the (inclusive) lower bound for the metadata field
        value. The value of a field must be greater than (`gt`) or
        equal to this value for the search query to match this
        template., defaults to None
                :type gt: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.lt = lt
        self.gt = gt



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_user_v2025_r0 import (
    HubCollaborationUserV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.group_mini_v2025_r0 import GroupMiniV2025R0

from box_sdk_gen.schemas.v2025_r0.hub_base_v2025_r0 import HubBaseV2025R0

from box_sdk_gen.schemas.v2025_r0.hub_access_grantee_v2025_r0 import (
    HubAccessGranteeV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.terms_of_service_base_v2025_r0 import (
    TermsOfServiceBaseV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class HubCollaborationV2025R0TypeField(str, Enum):
    HUB_COLLABORATION = 'hub_collaboration'


class HubCollaborationV2025R0StatusField(str, Enum):
    ACCEPTED = 'accepted'
    PENDING = 'pending'
    REJECTED = 'rejected'


class HubCollaborationV2025R0AcceptanceRequirementsStatusTermsOfServiceRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        is_accepted: Optional[bool] = None,
        terms_of_service: Optional[TermsOfServiceBaseV2025R0] = None,
        **kwargs
    ):
        """
                :param is_accepted: Whether or not the terms of service have been accepted.  The
        field is `null` when there is no terms of service required., defaults to None
                :type is_accepted: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_accepted = is_accepted
        self.terms_of_service = terms_of_service


class HubCollaborationV2025R0AcceptanceRequirementsStatusStrongPasswordRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        enterprise_has_strong_password_required_for_external_users: Optional[
            bool
        ] = None,
        user_has_strong_password: Optional[bool] = None,
        **kwargs
    ):
        """
                :param enterprise_has_strong_password_required_for_external_users: Whether or not the enterprise that owns the content requires
        a strong password to collaborate on the content, or enforces
        an exposed password detection for the external collaborators., defaults to None
                :type enterprise_has_strong_password_required_for_external_users: Optional[bool], optional
                :param user_has_strong_password: Whether or not the user has a strong and not exposed password set
        for their account. The field is `null` when a strong password is
        not required., defaults to None
                :type user_has_strong_password: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.enterprise_has_strong_password_required_for_external_users = (
            enterprise_has_strong_password_required_for_external_users
        )
        self.user_has_strong_password = user_has_strong_password


class HubCollaborationV2025R0AcceptanceRequirementsStatusTwoFactorAuthenticationRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        enterprise_has_two_factor_auth_enabled: Optional[bool] = None,
        user_has_two_factor_authentication_enabled: Optional[bool] = None,
        **kwargs
    ):
        """
                :param enterprise_has_two_factor_auth_enabled: Whether or not the enterprise that owns the content requires
        two-factor authentication to be enabled in order to
        collaborate on the content., defaults to None
                :type enterprise_has_two_factor_auth_enabled: Optional[bool], optional
                :param user_has_two_factor_authentication_enabled: Whether or not the user has two-factor authentication
        enabled. The field is `null` when two-factor
        authentication is not required., defaults to None
                :type user_has_two_factor_authentication_enabled: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.enterprise_has_two_factor_auth_enabled = (
            enterprise_has_two_factor_auth_enabled
        )
        self.user_has_two_factor_authentication_enabled = (
            user_has_two_factor_authentication_enabled
        )


class HubCollaborationV2025R0AcceptanceRequirementsStatusField(BaseObject):
    def __init__(
        self,
        *,
        terms_of_service_requirement: Optional[
            HubCollaborationV2025R0AcceptanceRequirementsStatusTermsOfServiceRequirementField
        ] = None,
        strong_password_requirement: Optional[
            HubCollaborationV2025R0AcceptanceRequirementsStatusStrongPasswordRequirementField
        ] = None,
        two_factor_authentication_requirement: Optional[
            HubCollaborationV2025R0AcceptanceRequirementsStatusTwoFactorAuthenticationRequirementField
        ] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.terms_of_service_requirement = terms_of_service_requirement
        self.strong_password_requirement = strong_password_requirement
        self.two_factor_authentication_requirement = (
            two_factor_authentication_requirement
        )


class HubCollaborationV2025R0(BaseObject):
    _discriminator = 'type', {'hub_collaboration'}

    def __init__(
        self,
        id: str,
        *,
        type: HubCollaborationV2025R0TypeField = HubCollaborationV2025R0TypeField.HUB_COLLABORATION,
        hub: Optional[HubBaseV2025R0] = None,
        accessible_by: Optional[HubAccessGranteeV2025R0] = None,
        role: Optional[str] = None,
        status: Optional[HubCollaborationV2025R0StatusField] = None,
        acceptance_requirements_status: Optional[
            HubCollaborationV2025R0AcceptanceRequirementsStatusField
        ] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this collaboration.
                :type id: str
                :param type: The value will always be `hub_collaboration`., defaults to HubCollaborationV2025R0TypeField.HUB_COLLABORATION
                :type type: HubCollaborationV2025R0TypeField, optional
                :param role: The level of access granted to a Box Hub.
        Possible values are `editor`, `viewer`, and `co-owner`., defaults to None
                :type role: Optional[str], optional
                :param status: The status of the collaboration invitation. If the status
        is `pending`, `login` and `name` return an empty string., defaults to None
                :type status: Optional[HubCollaborationV2025R0StatusField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.hub = hub
        self.accessible_by = accessible_by
        self.role = role
        self.status = status
        self.acceptance_requirements_status = acceptance_requirements_status



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class HubBaseV2025R0TypeField(str, Enum):
    HUBS = 'hubs'


class HubBaseV2025R0(BaseObject):
    _discriminator = 'type', {'hubs'}

    def __init__(
        self,
        id: str,
        *,
        type: HubBaseV2025R0TypeField = HubBaseV2025R0TypeField.HUBS,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a Box Hub.

        The ID for any Box Hub can be determined
        by visiting a Box Hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
                :type id: str
                :param type: The value will always be `hubs`., defaults to HubBaseV2025R0TypeField.HUBS
                :type type: HubBaseV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.users import Users

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.user_full import UserFull

from box_sdk_gen.schemas.tracking_code import TrackingCode

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetUsersUserType(str, Enum):
    ALL = 'all'
    MANAGED = 'managed'
    EXTERNAL = 'external'


class CreateUserRole(str, Enum):
    COADMIN = 'coadmin'
    USER = 'user'


class CreateUserStatus(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'
    CANNOT_DELETE_EDIT = 'cannot_delete_edit'
    CANNOT_DELETE_EDIT_UPLOAD = 'cannot_delete_edit_upload'


class UpdateUserByIdRole(str, Enum):
    COADMIN = 'coadmin'
    USER = 'user'


class UpdateUserByIdStatus(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'
    CANNOT_DELETE_EDIT = 'cannot_delete_edit'
    CANNOT_DELETE_EDIT_UPLOAD = 'cannot_delete_edit_upload'


class UpdateUserByIdNotificationEmail(BaseObject):
    def __init__(self, *, email: Optional[str] = None, **kwargs):
        """
        :param email: The email address to send the notifications to., defaults to None
        :type email: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.email = email


class UsersManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_users(
        self,
        *,
        filter_term: Optional[str] = None,
        user_type: Optional[GetUsersUserType] = None,
        external_app_user_id: Optional[str] = None,
        fields: Optional[List[str]] = None,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        usemarker: Optional[bool] = None,
        marker: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Users:
        """
                Returns a list of all users for the Enterprise along with their `user_id`,

                `public_name`, and `login`.


                The application and the authenticated user need to


                have the permission to look up users in the entire


                enterprise.

                :param filter_term: Limits the results to only users who's `name` or
        `login` start with the search term.

        For externally managed users, the search term needs
        to completely match the in order to find the user, and
        it will only return one user at a time., defaults to None
                :type filter_term: Optional[str], optional
                :param user_type: Limits the results to the kind of user specified.

        * `all` returns every kind of user for whom the
          `login` or `name` partially matches the
          `filter_term`. It will only return an external user
          if the login matches the `filter_term` completely,
          and in that case it will only return that user.
        * `managed` returns all managed and app users for whom
          the `login` or `name` partially matches the
          `filter_term`.
        * `external` returns all external users for whom the
          `login` matches the `filter_term` exactly., defaults to None
                :type user_type: Optional[GetUsersUserType], optional
                :param external_app_user_id: Limits the results to app users with the given
        `external_app_user_id` value.

        When creating an app user, an
        `external_app_user_id` value can be set. This value can
        then be used in this endpoint to find any users that
        match that `external_app_user_id` value., defaults to None
                :type external_app_user_id: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param usemarker: Specifies whether to use marker-based pagination instead of
        offset-based pagination. Only one pagination method can
        be used at a time.

        By setting this value to true, the API will return a `marker` field
        that can be passed as a parameter to this endpoint to get the next
        page of the response., defaults to None
                :type usemarker: Optional[bool], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'filter_term': to_string(filter_term),
                'user_type': to_string(user_type),
                'external_app_user_id': to_string(external_app_user_id),
                'fields': to_string(fields),
                'offset': to_string(offset),
                'limit': to_string(limit),
                'usemarker': to_string(usemarker),
                'marker': to_string(marker),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/users']),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Users)

    def create_user(
        self,
        name: str,
        *,
        login: Optional[str] = None,
        is_platform_access_only: Optional[bool] = None,
        role: Optional[CreateUserRole] = None,
        language: Optional[str] = None,
        is_sync_enabled: Optional[bool] = None,
        job_title: Optional[str] = None,
        phone: Optional[str] = None,
        address: Optional[str] = None,
        space_amount: Optional[int] = None,
        tracking_codes: Optional[List[TrackingCode]] = None,
        can_see_managed_users: Optional[bool] = None,
        timezone: Optional[str] = None,
        is_external_collab_restricted: Optional[bool] = None,
        is_exempt_from_device_limits: Optional[bool] = None,
        is_exempt_from_login_verification: Optional[bool] = None,
        status: Optional[CreateUserStatus] = None,
        external_app_user_id: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UserFull:
        """
                Creates a new managed user in an enterprise. This endpoint

                is only available to users and applications with the right


                admin permissions.

                :param name: The name of the user.
                :type name: str
                :param login: The email address the user uses to log in

        Required, unless `is_platform_access_only`
        is set to `true`., defaults to None
                :type login: Optional[str], optional
                :param is_platform_access_only: Specifies that the user is an app user., defaults to None
                :type is_platform_access_only: Optional[bool], optional
                :param role: The user’s enterprise role., defaults to None
                :type role: Optional[CreateUserRole], optional
                :param language: The language of the user, formatted in modified version of the
        [ISO 639-1](https://developer.box.com/guides/api-calls/language-codes) format., defaults to None
                :type language: Optional[str], optional
                :param is_sync_enabled: Whether the user can use Box Sync., defaults to None
                :type is_sync_enabled: Optional[bool], optional
                :param job_title: The user’s job title., defaults to None
                :type job_title: Optional[str], optional
                :param phone: The user’s phone number., defaults to None
                :type phone: Optional[str], optional
                :param address: The user’s address., defaults to None
                :type address: Optional[str], optional
                :param space_amount: The user’s total available space in bytes. Set this to `-1` to
        indicate unlimited storage., defaults to None
                :type space_amount: Optional[int], optional
                :param tracking_codes: Tracking codes allow an admin to generate reports from the
        admin console and assign an attribute to a specific group
        of users. This setting must be enabled for an enterprise before it
        can be used., defaults to None
                :type tracking_codes: Optional[List[TrackingCode]], optional
                :param can_see_managed_users: Whether the user can see other enterprise users in their
        contact list., defaults to None
                :type can_see_managed_users: Optional[bool], optional
                :param timezone: The user's timezone., defaults to None
                :type timezone: Optional[str], optional
                :param is_external_collab_restricted: Whether the user is allowed to collaborate with users outside
        their enterprise., defaults to None
                :type is_external_collab_restricted: Optional[bool], optional
                :param is_exempt_from_device_limits: Whether to exempt the user from enterprise device limits., defaults to None
                :type is_exempt_from_device_limits: Optional[bool], optional
                :param is_exempt_from_login_verification: Whether the user must use two-factor authentication., defaults to None
                :type is_exempt_from_login_verification: Optional[bool], optional
                :param status: The user's account status., defaults to None
                :type status: Optional[CreateUserStatus], optional
                :param external_app_user_id: An external identifier for an app user, which can be used to look
        up the user. This can be used to tie user IDs from external
        identity providers to Box users., defaults to None
                :type external_app_user_id: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'name': name,
            'login': login,
            'is_platform_access_only': is_platform_access_only,
            'role': role,
            'language': language,
            'is_sync_enabled': is_sync_enabled,
            'job_title': job_title,
            'phone': phone,
            'address': address,
            'space_amount': space_amount,
            'tracking_codes': tracking_codes,
            'can_see_managed_users': can_see_managed_users,
            'timezone': timezone,
            'is_external_collab_restricted': is_external_collab_restricted,
            'is_exempt_from_device_limits': is_exempt_from_device_limits,
            'is_exempt_from_login_verification': is_exempt_from_login_verification,
            'status': status,
            'external_app_user_id': external_app_user_id,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/users']),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UserFull)

    def get_user_me(
        self,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UserFull:
        """
                Retrieves information about the user who is currently authenticated.

                In the case of a client-side authenticated OAuth 2.0 application


                this will be the user who authorized the app.


                In the case of a JWT, server-side authenticated application


                this will be the service account that belongs to the application


                by default.


                Use the `As-User` header to change who this API call is made on behalf of.

                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/users/me']),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UserFull)

    def get_user_by_id(
        self,
        user_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UserFull:
        """
                Retrieves information about a user in the enterprise.

                The application and the authenticated user need to


                have the permission to look up users in the entire


                enterprise.


                This endpoint also returns a limited set of information


                for external users who are collaborated on content


                owned by the enterprise for authenticated users with the


                right scopes. In this case, disallowed fields will return


                null instead.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UserFull)

    def update_user_by_id(
        self,
        user_id: str,
        *,
        enterprise: Union[Optional[str], NullValue] = None,
        notify: Optional[bool] = None,
        name: Optional[str] = None,
        login: Optional[str] = None,
        role: Optional[UpdateUserByIdRole] = None,
        language: Optional[str] = None,
        is_sync_enabled: Optional[bool] = None,
        job_title: Optional[str] = None,
        phone: Optional[str] = None,
        address: Optional[str] = None,
        tracking_codes: Optional[List[TrackingCode]] = None,
        can_see_managed_users: Optional[bool] = None,
        timezone: Optional[str] = None,
        is_external_collab_restricted: Optional[bool] = None,
        is_exempt_from_device_limits: Optional[bool] = None,
        is_exempt_from_login_verification: Optional[bool] = None,
        is_password_reset_required: Optional[bool] = None,
        status: Optional[UpdateUserByIdStatus] = None,
        space_amount: Optional[int] = None,
        notification_email: Union[
            Optional[UpdateUserByIdNotificationEmail], NullValue
        ] = None,
        external_app_user_id: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UserFull:
        """
                Updates a managed or app user in an enterprise. This endpoint

                is only available to users and applications with the right


                admin permissions.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param enterprise: Set this to `null` to roll the user out of the enterprise
        and make them a free user., defaults to None
                :type enterprise: Union[Optional[str], NullValue], optional
                :param notify: Whether the user should receive an email when they
        are rolled out of an enterprise., defaults to None
                :type notify: Optional[bool], optional
                :param name: The name of the user., defaults to None
                :type name: Optional[str], optional
                :param login: The email address the user uses to log in

        Note: If the target user's email is not confirmed, then the
        primary login address cannot be changed., defaults to None
                :type login: Optional[str], optional
                :param role: The user’s enterprise role., defaults to None
                :type role: Optional[UpdateUserByIdRole], optional
                :param language: The language of the user, formatted in modified version of the
        [ISO 639-1](https://developer.box.com/guides/api-calls/language-codes) format., defaults to None
                :type language: Optional[str], optional
                :param is_sync_enabled: Whether the user can use Box Sync., defaults to None
                :type is_sync_enabled: Optional[bool], optional
                :param job_title: The user’s job title., defaults to None
                :type job_title: Optional[str], optional
                :param phone: The user’s phone number., defaults to None
                :type phone: Optional[str], optional
                :param address: The user’s address., defaults to None
                :type address: Optional[str], optional
                :param tracking_codes: Tracking codes allow an admin to generate reports from the
        admin console and assign an attribute to a specific group
        of users. This setting must be enabled for an enterprise before it
        can be used., defaults to None
                :type tracking_codes: Optional[List[TrackingCode]], optional
                :param can_see_managed_users: Whether the user can see other enterprise users in their
        contact list., defaults to None
                :type can_see_managed_users: Optional[bool], optional
                :param timezone: The user's timezone., defaults to None
                :type timezone: Optional[str], optional
                :param is_external_collab_restricted: Whether the user is allowed to collaborate with users outside
        their enterprise., defaults to None
                :type is_external_collab_restricted: Optional[bool], optional
                :param is_exempt_from_device_limits: Whether to exempt the user from enterprise device limits., defaults to None
                :type is_exempt_from_device_limits: Optional[bool], optional
                :param is_exempt_from_login_verification: Whether the user must use two-factor authentication., defaults to None
                :type is_exempt_from_login_verification: Optional[bool], optional
                :param is_password_reset_required: Whether the user is required to reset their password., defaults to None
                :type is_password_reset_required: Optional[bool], optional
                :param status: The user's account status., defaults to None
                :type status: Optional[UpdateUserByIdStatus], optional
                :param space_amount: The user’s total available space in bytes. Set this to `-1` to
        indicate unlimited storage., defaults to None
                :type space_amount: Optional[int], optional
                :param notification_email: An alternate notification email address to which email
        notifications are sent. When it's confirmed, this will be
        the email address to which notifications are sent instead of
        to the primary email address.

        Set this value to `null` to remove the notification email., defaults to None
                :type notification_email: Union[Optional[UpdateUserByIdNotificationEmail], NullValue], optional
                :param external_app_user_id: An external identifier for an app user, which can be used to look
        up the user. This can be used to tie user IDs from external
        identity providers to Box users.

        Note: In order to update this field, you need to request a token
        using the application that created the app user., defaults to None
                :type external_app_user_id: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'enterprise': enterprise,
            'notify': notify,
            'name': name,
            'login': login,
            'role': role,
            'language': language,
            'is_sync_enabled': is_sync_enabled,
            'job_title': job_title,
            'phone': phone,
            'address': address,
            'tracking_codes': tracking_codes,
            'can_see_managed_users': can_see_managed_users,
            'timezone': timezone,
            'is_external_collab_restricted': is_external_collab_restricted,
            'is_exempt_from_device_limits': is_exempt_from_device_limits,
            'is_exempt_from_login_verification': is_exempt_from_login_verification,
            'is_password_reset_required': is_password_reset_required,
            'status': status,
            'space_amount': space_amount,
            'notification_email': notification_email,
            'external_app_user_id': external_app_user_id,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UserFull)

    def delete_user_by_id(
        self,
        user_id: str,
        *,
        notify: Optional[bool] = None,
        force: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a user. By default, this operation fails if the user

                still owns any content, was recently active, or recently joined the enterprise from a free account.


                To proceed, move their owned content first, or use the `force` parameter to delete


                the user and their files.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param notify: Whether the user will receive email notification of
        the deletion., defaults to None
                :type notify: Optional[bool], optional
                :param force: Specifies whether to delete the user even if they still own files,
        were recently active, or recently joined the enterprise from a free account., defaults to None
                :type force: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'notify': to_string(notify), 'force': to_string(force)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                    ]
                ),
                method='DELETE',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class CustomSessionDurationGroupItemV2025R0(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, name: Optional[str] = None, **kwargs
    ):
        """
        :param id: Group ID (numerical)., defaults to None
        :type id: Optional[str], optional
        :param name: Group Name., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.name = name



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.shield_information_barrier_base import (
    ShieldInformationBarrierBase,
)

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class ShieldInformationBarrierSegmentTypeField(str, Enum):
    SHIELD_INFORMATION_BARRIER_SEGMENT = 'shield_information_barrier_segment'


class ShieldInformationBarrierSegment(BaseObject):
    _discriminator = 'type', {'shield_information_barrier_segment'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[ShieldInformationBarrierSegmentTypeField] = None,
        shield_information_barrier: Optional[ShieldInformationBarrierBase] = None,
        name: Optional[str] = None,
        description: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        created_by: Optional[UserBase] = None,
        updated_at: Optional[DateTime] = None,
        updated_by: Optional[UserBase] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for the shield information barrier segment., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information barrier segment., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentTypeField], optional
                :param name: Name of the shield information barrier segment., defaults to None
                :type name: Optional[str], optional
                :param description: Description of the shield information barrier segment., defaults to None
                :type description: Optional[str], optional
                :param created_at: ISO date time string when this shield information
        barrier object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param updated_at: ISO date time string when this
        shield information barrier segment was updated., defaults to None
                :type updated_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.shield_information_barrier = shield_information_barrier
        self.name = name
        self.description = description
        self.created_at = created_at
        self.created_by = created_by
        self.updated_at = updated_at
        self.updated_by = updated_by



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_long_text_tool import AiAgentLongTextTool

from box_sdk_gen.schemas.ai_agent_basic_text_tool import AiAgentBasicTextTool

from box_sdk_gen.schemas.ai_agent_spreadsheet_tool import AiAgentSpreadsheetTool

from box_sdk_gen.box.errors import BoxSDKError


class AiAgentAskTypeField(str, Enum):
    AI_AGENT_ASK = 'ai_agent_ask'


class AiAgentAsk(BaseObject):
    _discriminator = 'type', {'ai_agent_ask'}

    def __init__(
        self,
        *,
        type: AiAgentAskTypeField = AiAgentAskTypeField.AI_AGENT_ASK,
        long_text: Optional[AiAgentLongTextTool] = None,
        basic_text: Optional[AiAgentBasicTextTool] = None,
        spreadsheet: Optional[AiAgentSpreadsheetTool] = None,
        long_text_multi: Optional[AiAgentLongTextTool] = None,
        basic_text_multi: Optional[AiAgentBasicTextTool] = None,
        basic_image: Optional[AiAgentBasicTextTool] = None,
        basic_image_multi: Optional[AiAgentBasicTextTool] = None,
        **kwargs
    ):
        """
        :param type: The type of AI agent used to handle queries., defaults to AiAgentAskTypeField.AI_AGENT_ASK
        :type type: AiAgentAskTypeField, optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.long_text = long_text
        self.basic_text = basic_text
        self.spreadsheet = spreadsheet
        self.long_text_multi = long_text_multi
        self.basic_text_multi = basic_text_multi
        self.basic_image = basic_image
        self.basic_image_multi = basic_image_multi



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class PostOAuth2TokenGrantTypeField(str, Enum):
    AUTHORIZATION_CODE = 'authorization_code'
    REFRESH_TOKEN = 'refresh_token'
    CLIENT_CREDENTIALS = 'client_credentials'
    URN_IETF_PARAMS_OAUTH_GRANT_TYPE_JWT_BEARER = (
        'urn:ietf:params:oauth:grant-type:jwt-bearer'
    )
    URN_IETF_PARAMS_OAUTH_GRANT_TYPE_TOKEN_EXCHANGE = (
        'urn:ietf:params:oauth:grant-type:token-exchange'
    )


class PostOAuth2TokenSubjectTokenTypeField(str, Enum):
    URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN = (
        'urn:ietf:params:oauth:token-type:access_token'
    )


class PostOAuth2TokenActorTokenTypeField(str, Enum):
    URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ID_TOKEN = (
        'urn:ietf:params:oauth:token-type:id_token'
    )


class PostOAuth2TokenBoxSubjectTypeField(str, Enum):
    ENTERPRISE = 'enterprise'
    USER = 'user'


class PostOAuth2Token(BaseObject):
    def __init__(
        self,
        grant_type: PostOAuth2TokenGrantTypeField,
        *,
        client_id: Optional[str] = None,
        client_secret: Optional[str] = None,
        code: Optional[str] = None,
        refresh_token: Optional[str] = None,
        assertion: Optional[str] = None,
        subject_token: Optional[str] = None,
        subject_token_type: Optional[PostOAuth2TokenSubjectTokenTypeField] = None,
        actor_token: Optional[str] = None,
        actor_token_type: Optional[PostOAuth2TokenActorTokenTypeField] = None,
        scope: Optional[str] = None,
        resource: Optional[str] = None,
        box_subject_type: Optional[PostOAuth2TokenBoxSubjectTypeField] = None,
        box_subject_id: Optional[str] = None,
        box_shared_link: Optional[str] = None,
        **kwargs
    ):
        """
                :param grant_type: The type of request being made, either using a client-side obtained
        authorization code, a refresh token, a JWT assertion, client credentials
        grant or another access token for the purpose of downscoping a token.
                :type grant_type: PostOAuth2TokenGrantTypeField
                :param client_id: The Client ID of the application requesting an access token.

        Used in combination with `authorization_code`, `client_credentials`, or
        `urn:ietf:params:oauth:grant-type:jwt-bearer` as the `grant_type`., defaults to None
                :type client_id: Optional[str], optional
                :param client_secret: The client secret of the application requesting an access token.

        Used in combination with `authorization_code`, `client_credentials`, or
        `urn:ietf:params:oauth:grant-type:jwt-bearer` as the `grant_type`., defaults to None
                :type client_secret: Optional[str], optional
                :param code: The client-side authorization code passed to your application by
        Box in the browser redirect after the user has successfully
        granted your application permission to make API calls on their
        behalf.

        Used in combination with `authorization_code` as the `grant_type`., defaults to None
                :type code: Optional[str], optional
                :param refresh_token: A refresh token used to get a new access token with.

        Used in combination with `refresh_token` as the `grant_type`., defaults to None
                :type refresh_token: Optional[str], optional
                :param assertion: A JWT assertion for which to request a new access token.

        Used in combination with `urn:ietf:params:oauth:grant-type:jwt-bearer`
        as the `grant_type`., defaults to None
                :type assertion: Optional[str], optional
                :param subject_token: The token to exchange for a downscoped token. This can be a regular
        access token, a JWT assertion, or an app token.

        Used in combination with `urn:ietf:params:oauth:grant-type:token-exchange`
        as the `grant_type`., defaults to None
                :type subject_token: Optional[str], optional
                :param subject_token_type: The type of `subject_token` passed in.

        Used in combination with `urn:ietf:params:oauth:grant-type:token-exchange`
        as the `grant_type`., defaults to None
                :type subject_token_type: Optional[PostOAuth2TokenSubjectTokenTypeField], optional
                :param actor_token: The token used to create an annotator token.
        This is a JWT assertion.

        Used in combination with `urn:ietf:params:oauth:grant-type:token-exchange`
        as the `grant_type`., defaults to None
                :type actor_token: Optional[str], optional
                :param actor_token_type: The type of `actor_token` passed in.

        Used in combination with `urn:ietf:params:oauth:grant-type:token-exchange`
        as the `grant_type`., defaults to None
                :type actor_token_type: Optional[PostOAuth2TokenActorTokenTypeField], optional
                :param scope: The space-delimited list of scopes that you want apply to the
        new access token.

        The `subject_token` will need to have all of these scopes or
        the call will error with **401 Unauthorized**.., defaults to None
                :type scope: Optional[str], optional
                :param resource: Full URL for the file that the token should be generated for., defaults to None
                :type resource: Optional[str], optional
                :param box_subject_type: Used in combination with `client_credentials` as the `grant_type`., defaults to None
                :type box_subject_type: Optional[PostOAuth2TokenBoxSubjectTypeField], optional
                :param box_subject_id: Used in combination with `client_credentials` as the `grant_type`.
        Value is determined by `box_subject_type`. If `user` use user ID and if
        `enterprise` use enterprise ID., defaults to None
                :type box_subject_id: Optional[str], optional
                :param box_shared_link: Full URL of the shared link on the file or folder
        that the token should be generated for., defaults to None
                :type box_shared_link: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.grant_type = grant_type
        self.client_id = client_id
        self.client_secret = client_secret
        self.code = code
        self.refresh_token = refresh_token
        self.assertion = assertion
        self.subject_token = subject_token
        self.subject_token_type = subject_token_type
        self.actor_token = actor_token
        self.actor_token_type = actor_token_type
        self.scope = scope
        self.resource = resource
        self.box_subject_type = box_subject_type
        self.box_subject_id = box_subject_id
        self.box_shared_link = box_shared_link



from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.folder_base import FolderBaseTypeField

from box_sdk_gen.schemas.folder_base import FolderBase

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.items import Items

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FolderPathCollectionField(BaseObject):
    def __init__(self, total_count: int, entries: List[FolderMini], **kwargs):
        """
        :param total_count: The number of folders in this list.
        :type total_count: int
        :param entries: The parent folders for this item.
        :type entries: List[FolderMini]
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.entries = entries


class FolderSharedLinkAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class FolderSharedLinkEffectiveAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class FolderSharedLinkEffectivePermissionField(str, Enum):
    CAN_EDIT = 'can_edit'
    CAN_DOWNLOAD = 'can_download'
    CAN_PREVIEW = 'can_preview'
    NO_ACCESS = 'no_access'


class FolderSharedLinkPermissionsField(BaseObject):
    def __init__(self, can_download: bool, can_preview: bool, can_edit: bool, **kwargs):
        """
                :param can_download: Defines if the shared link allows for the item to be downloaded. For
        shared links on folders, this also applies to any items in the folder.

        This value can be set to `true` when the effective access level is
        set to `open` or `company`, not `collaborators`.
                :type can_download: bool
                :param can_preview: Defines if the shared link allows for the item to be previewed.

        This value is always `true`. For shared links on folders this also
        applies to any items in the folder.
                :type can_preview: bool
                :param can_edit: Defines if the shared link allows for the item to be edited.

        This value can only be `true` if `can_download` is also `true` and if
        the item has a type of `file`.
                :type can_edit: bool
        """
        super().__init__(**kwargs)
        self.can_download = can_download
        self.can_preview = can_preview
        self.can_edit = can_edit


class FolderSharedLinkField(BaseObject):
    def __init__(
        self,
        url: str,
        effective_access: FolderSharedLinkEffectiveAccessField,
        effective_permission: FolderSharedLinkEffectivePermissionField,
        is_password_enabled: bool,
        download_count: int,
        preview_count: int,
        *,
        download_url: Optional[str] = None,
        vanity_url: Optional[str] = None,
        vanity_name: Optional[str] = None,
        access: Optional[FolderSharedLinkAccessField] = None,
        unshared_at: Optional[DateTime] = None,
        permissions: Optional[FolderSharedLinkPermissionsField] = None,
        **kwargs
    ):
        """
                :param url: The URL that can be used to access the item on Box.

        This URL will display the item in Box's preview UI where the file
        can be downloaded if allowed.

        This URL will continue to work even when a custom `vanity_url`
        has been set for this shared link.
                :type url: str
                :param effective_access: The effective access level for the shared link. This can be a more
        restrictive access level than the value in the `access` field when the
        enterprise settings restrict the allowed access levels.
                :type effective_access: FolderSharedLinkEffectiveAccessField
                :param effective_permission: The effective permissions for this shared link.
        These result in the more restrictive combination of
        the share link permissions and the item permissions set
        by the administrator, the owner, and any ancestor item
        such as a folder.
                :type effective_permission: FolderSharedLinkEffectivePermissionField
                :param is_password_enabled: Defines if the shared link requires a password to access the item.
                :type is_password_enabled: bool
                :param download_count: The number of times this item has been downloaded.
                :type download_count: int
                :param preview_count: The number of times this item has been previewed.
                :type preview_count: int
                :param download_url: A URL that can be used to download the file. This URL can be used in
        a browser to download the file. This URL includes the file
        extension so that the file will be saved with the right file type.

        This property will be `null` for folders., defaults to None
                :type download_url: Optional[str], optional
                :param vanity_url: The "Custom URL" that can also be used to preview the item on Box.  Custom
        URLs can only be created or modified in the Box Web application., defaults to None
                :type vanity_url: Optional[str], optional
                :param vanity_name: The custom name of a shared link, as used in the `vanity_url` field., defaults to None
                :type vanity_name: Optional[str], optional
                :param access: The access level for this shared link.

        * `open` - provides access to this item to anyone with this link
        * `company` - only provides access to this item to people the same company
        * `collaborators` - only provides access to this item to people who are
           collaborators on this item

        If this field is omitted when creating the shared link, the access level
        will be set to the default access level specified by the enterprise admin., defaults to None
                :type access: Optional[FolderSharedLinkAccessField], optional
                :param unshared_at: The date and time when this link will be unshared. This field can only be
        set by users with paid accounts., defaults to None
                :type unshared_at: Optional[DateTime], optional
                :param permissions: Defines if this link allows a user to preview, edit, and download an item.
        These permissions refer to the shared link only and
        do not supersede permissions applied to the item itself., defaults to None
                :type permissions: Optional[FolderSharedLinkPermissionsField], optional
        """
        super().__init__(**kwargs)
        self.url = url
        self.effective_access = effective_access
        self.effective_permission = effective_permission
        self.is_password_enabled = is_password_enabled
        self.download_count = download_count
        self.preview_count = preview_count
        self.download_url = download_url
        self.vanity_url = vanity_url
        self.vanity_name = vanity_name
        self.access = access
        self.unshared_at = unshared_at
        self.permissions = permissions


class FolderFolderUploadEmailAccessField(str, Enum):
    OPEN = 'open'
    COLLABORATORS = 'collaborators'


class FolderFolderUploadEmailField(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[FolderFolderUploadEmailAccessField] = None,
        email: Optional[str] = None,
        **kwargs
    ):
        """
                :param access: When this parameter has been set, users can email files
        to the email address that has been automatically
        created for this folder.

        To create an email address, set this property either when
        creating or updating the folder.

        When set to `collaborators`, only emails from registered email
        addresses for collaborators will be accepted. This includes
        any email aliases a user might have registered.

        When set to `open` it will accept emails from any email
        address., defaults to None
                :type access: Optional[FolderFolderUploadEmailAccessField], optional
                :param email: The optional upload email address for this folder., defaults to None
                :type email: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.email = email


class FolderItemStatusField(str, Enum):
    ACTIVE = 'active'
    TRASHED = 'trashed'
    DELETED = 'deleted'


class Folder(FolderMini):
    def __init__(
        self,
        id: str,
        *,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        description: Optional[str] = None,
        size: Optional[int] = None,
        path_collection: Optional[FolderPathCollectionField] = None,
        created_by: Optional[UserMini] = None,
        modified_by: Optional[UserMini] = None,
        trashed_at: Optional[DateTime] = None,
        purged_at: Optional[DateTime] = None,
        content_created_at: Optional[DateTime] = None,
        content_modified_at: Optional[DateTime] = None,
        owned_by: Optional[UserMini] = None,
        shared_link: Optional[FolderSharedLinkField] = None,
        folder_upload_email: Optional[FolderFolderUploadEmailField] = None,
        parent: Optional[FolderMini] = None,
        item_status: Optional[FolderItemStatusField] = None,
        item_collection: Optional[Items] = None,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        etag: Optional[str] = None,
        type: FolderBaseTypeField = FolderBaseTypeField.FOLDER,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting a folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folders/123`
        the `folder_id` is `123`.
                :type id: str
                :param created_at: The date and time when the folder was created. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: The date and time when the folder was last updated. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param size: The folder size in bytes.

        Be careful parsing this integer as its
        value can get very large., defaults to None
                :type size: Optional[int], optional
                :param trashed_at: The time at which this folder was put in the trash., defaults to None
                :type trashed_at: Optional[DateTime], optional
                :param purged_at: The time at which this folder is expected to be purged
        from the trash., defaults to None
                :type purged_at: Optional[DateTime], optional
                :param content_created_at: The date and time at which this folder was originally
        created., defaults to None
                :type content_created_at: Optional[DateTime], optional
                :param content_modified_at: The date and time at which this folder was last updated., defaults to None
                :type content_modified_at: Optional[DateTime], optional
                :param folder_upload_email: The `folder_upload_email` parameter is not `null` if one of the following options is **true**:

          * The **Allow uploads to this folder via email** and the **Only allow email uploads from collaborators in this folder** are [enabled for a folder in the Admin Console](https://support.box.com/hc/en-us/articles/360043697534-Upload-to-Box-Through-Email), and the user has at least **Upload** permissions granted.

          * The **Allow uploads to this folder via email** setting is enabled for a folder in the Admin Console, and the **Only allow email uploads from collaborators in this folder** setting is deactivated (unchecked).

        If the conditions are not met, the parameter will have the following value: `folder_upload_email: null`., defaults to None
                :type folder_upload_email: Optional[FolderFolderUploadEmailField], optional
                :param item_status: Defines if this item has been deleted or not.

        * `active` when the item has is not in the trash
        * `trashed` when the item has been moved to the trash but not deleted
        * `deleted` when the item has been permanently deleted., defaults to None
                :type item_status: Optional[FolderItemStatusField], optional
                :param name: The name of the folder., defaults to None
                :type name: Optional[str], optional
                :param etag: The HTTP `etag` of this folder. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the folder if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `folder`., defaults to FolderBaseTypeField.FOLDER
                :type type: FolderBaseTypeField, optional
        """
        super().__init__(
            id=id, sequence_id=sequence_id, name=name, etag=etag, type=type, **kwargs
        )
        self.created_at = created_at
        self.modified_at = modified_at
        self.description = description
        self.size = size
        self.path_collection = path_collection
        self.created_by = created_by
        self.modified_by = modified_by
        self.trashed_at = trashed_at
        self.purged_at = purged_at
        self.content_created_at = content_created_at
        self.content_modified_at = content_modified_at
        self.owned_by = owned_by
        self.shared_link = shared_link
        self.folder_upload_email = folder_upload_email
        self.parent = parent
        self.item_status = item_status
        self.item_collection = item_collection



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError


class ClassificationTemplateTypeField(str, Enum):
    METADATA_TEMPLATE = 'metadata_template'


class ClassificationTemplateTemplateKeyField(str, Enum):
    SECURITYCLASSIFICATION_6VMVOCHWUWO = 'securityClassification-6VMVochwUWo'


class ClassificationTemplateDisplayNameField(str, Enum):
    CLASSIFICATION = 'Classification'


class ClassificationTemplateFieldsTypeField(str, Enum):
    ENUM = 'enum'


class ClassificationTemplateFieldsKeyField(str, Enum):
    BOX__SECURITY__CLASSIFICATION__KEY = 'Box__Security__Classification__Key'


class ClassificationTemplateFieldsDisplayNameField(str, Enum):
    CLASSIFICATION = 'Classification'


class ClassificationTemplateFieldsOptionsStaticConfigClassificationField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'classification_definition': 'classificationDefinition',
        'color_id': 'colorID',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'classificationDefinition': 'classification_definition',
        'colorID': 'color_id',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        classification_definition: Optional[str] = None,
        color_id: Optional[int] = None,
        **kwargs
    ):
        """
                :param classification_definition: A longer description of the classification., defaults to None
                :type classification_definition: Optional[str], optional
                :param color_id: An internal Box identifier used to assign a color to
        a classification label.

        Mapping between a `colorID` and a color may change
        without notice. Currently, the color mappings are as
        follows.

        * `0`: Yellow.
        * `1`: Orange.
        * `2`: Watermelon red.
        * `3`: Purple rain.
        * `4`: Light blue.
        * `5`: Dark blue.
        * `6`: Light green.
        * `7`: Gray., defaults to None
                :type color_id: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.classification_definition = classification_definition
        self.color_id = color_id


class ClassificationTemplateFieldsOptionsStaticConfigField(BaseObject):
    def __init__(
        self,
        *,
        classification: Optional[
            ClassificationTemplateFieldsOptionsStaticConfigClassificationField
        ] = None,
        **kwargs
    ):
        """
                :param classification: Additional information about the classification.

        This is not an exclusive list of properties, and
        more object fields might be returned. These fields
        are used for internal Box Shield and Box Governance
        purposes and no additional value must be derived from
        these fields., defaults to None
                :type classification: Optional[ClassificationTemplateFieldsOptionsStaticConfigClassificationField], optional
        """
        super().__init__(**kwargs)
        self.classification = classification


class ClassificationTemplateFieldsOptionsField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'static_config': 'staticConfig',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'staticConfig': 'static_config',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        id: str,
        key: str,
        *,
        static_config: Optional[
            ClassificationTemplateFieldsOptionsStaticConfigField
        ] = None,
        **kwargs
    ):
        """
        :param id: The unique ID of this classification.
        :type id: str
        :param key: The display name and key for this classification.
        :type key: str
        :param static_config: Additional information about the classification., defaults to None
        :type static_config: Optional[ClassificationTemplateFieldsOptionsStaticConfigField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.key = key
        self.static_config = static_config


class ClassificationTemplateFieldsField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {'enum'}

    def __init__(
        self,
        id: str,
        options: List[ClassificationTemplateFieldsOptionsField],
        *,
        type: ClassificationTemplateFieldsTypeField = ClassificationTemplateFieldsTypeField.ENUM,
        key: ClassificationTemplateFieldsKeyField = ClassificationTemplateFieldsKeyField.BOX__SECURITY__CLASSIFICATION__KEY,
        display_name: ClassificationTemplateFieldsDisplayNameField = ClassificationTemplateFieldsDisplayNameField.CLASSIFICATION,
        hidden: Optional[bool] = None,
        **kwargs
    ):
        """
                :param id: The unique ID of the field.
                :type id: str
                :param options: A list of classifications available in this enterprise.
                :type options: List[ClassificationTemplateFieldsOptionsField]
                :param type: The array item type., defaults to ClassificationTemplateFieldsTypeField.ENUM
                :type type: ClassificationTemplateFieldsTypeField, optional
                :param key: Defines classifications
        available in the enterprise., defaults to ClassificationTemplateFieldsKeyField.BOX__SECURITY__CLASSIFICATION__KEY
                :type key: ClassificationTemplateFieldsKeyField, optional
                :param display_name: The value will always be `Classification`., defaults to ClassificationTemplateFieldsDisplayNameField.CLASSIFICATION
                :type display_name: ClassificationTemplateFieldsDisplayNameField, optional
                :param hidden: Classifications are always visible to web and mobile users., defaults to None
                :type hidden: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.options = options
        self.type = type
        self.key = key
        self.display_name = display_name
        self.hidden = hidden


class ClassificationTemplate(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'template_key': 'templateKey',
        'display_name': 'displayName',
        'copy_instance_on_item_copy': 'copyInstanceOnItemCopy',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'templateKey': 'template_key',
        'displayName': 'display_name',
        'copyInstanceOnItemCopy': 'copy_instance_on_item_copy',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {'metadata_template'}

    def __init__(
        self,
        id: str,
        scope: str,
        fields: List[ClassificationTemplateFieldsField],
        *,
        type: ClassificationTemplateTypeField = ClassificationTemplateTypeField.METADATA_TEMPLATE,
        template_key: ClassificationTemplateTemplateKeyField = ClassificationTemplateTemplateKeyField.SECURITYCLASSIFICATION_6VMVOCHWUWO,
        display_name: ClassificationTemplateDisplayNameField = ClassificationTemplateDisplayNameField.CLASSIFICATION,
        hidden: Optional[bool] = None,
        copy_instance_on_item_copy: Optional[bool] = None,
        **kwargs
    ):
        """
                :param id: The ID of the classification template.
                :type id: str
                :param scope: The scope of the classification template. This is in the format
        `enterprise_{id}` where the `id` is the enterprise ID.
                :type scope: str
                :param fields: A list of fields for this classification template. This includes
        only one field, the `Box__Security__Classification__Key`, which defines
        the different classifications available in this enterprise.
                :type fields: List[ClassificationTemplateFieldsField]
                :param type: The value will always be `metadata_template`., defaults to ClassificationTemplateTypeField.METADATA_TEMPLATE
                :type type: ClassificationTemplateTypeField, optional
                :param template_key: The value will always be `securityClassification-6VMVochwUWo`., defaults to ClassificationTemplateTemplateKeyField.SECURITYCLASSIFICATION_6VMVOCHWUWO
                :type template_key: ClassificationTemplateTemplateKeyField, optional
                :param display_name: The name of this template as shown in web and mobile interfaces., defaults to ClassificationTemplateDisplayNameField.CLASSIFICATION
                :type display_name: ClassificationTemplateDisplayNameField, optional
                :param hidden: Determines if the
        template is always available in web and mobile interfaces., defaults to None
                :type hidden: Optional[bool], optional
                :param copy_instance_on_item_copy: Determines if
        classifications are
        copied along when the file or folder is
        copied., defaults to None
                :type copy_instance_on_item_copy: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.scope = scope
        self.fields = fields
        self.type = type
        self.template_key = template_key
        self.display_name = display_name
        self.hidden = hidden
        self.copy_instance_on_item_copy = copy_instance_on_item_copy



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.metadata import Metadata

from box_sdk_gen.box.errors import BoxSDKError


class Metadatas(BaseObject):
    def __init__(
        self,
        *,
        entries: Optional[List[Metadata]] = None,
        limit: Optional[int] = None,
        **kwargs
    ):
        """
        :param entries: A list of metadata instances, as applied to this file or folder., defaults to None
        :type entries: Optional[List[Metadata]], optional
        :param limit: The limit that was used for this page of results., defaults to None
        :type limit: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.entries = entries
        self.limit = limit



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.app_item_associations import AppItemAssociations

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class AppItemAssociationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_app_item_associations(
        self,
        file_id: str,
        *,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        application_type: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AppItemAssociations:
        """
                **This is a beta feature, which means that its availability might be limited.**

                Returns all app items the file is associated with. This includes app items


                associated with ancestors of the file. Assuming the context user has access


                to the file, the type/ids are revealed even if the context user does not


                have **View** permission on the app item.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param application_type: If given, only return app items for this application type., defaults to None
                :type application_type: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'limit': to_string(limit),
                'marker': to_string(marker),
                'application_type': to_string(application_type),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/app_item_associations',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AppItemAssociations)

    def get_folder_app_item_associations(
        self,
        folder_id: str,
        *,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        application_type: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AppItemAssociations:
        """
                **This is a beta feature, which means that its availability might be limited.**

                Returns all app items the folder is associated with. This includes app items


                associated with ancestors of the folder. Assuming the context user has access


                to the folder, the type/ids are revealed even if the context user does not


                have **View** permission on the app item.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param application_type: If given, returns only app items for this application type., defaults to None
                :type application_type: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'limit': to_string(limit),
                'marker': to_string(marker),
                'application_type': to_string(application_type),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/app_item_associations',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AppItemAssociations)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class FileBaseTypeField(str, Enum):
    FILE = 'file'


class FileBase(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        id: str,
        *,
        etag: Optional[str] = None,
        type: FileBaseTypeField = FileBaseTypeField.FILE,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
                :type id: str
                :param etag: The HTTP `etag` of this file. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the file if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `file`., defaults to FileBaseTypeField.FILE
                :type type: FileBaseTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.etag = etag
        self.type = type



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.realtime_server import RealtimeServer

from box_sdk_gen.box.errors import BoxSDKError


class RealtimeServers(BaseObject):
    def __init__(
        self,
        *,
        chunk_size: Optional[int] = None,
        entries: Optional[List[RealtimeServer]] = None,
        **kwargs
    ):
        """
        :param chunk_size: The number of items in this response., defaults to None
        :type chunk_size: Optional[int], optional
        :param entries: A list of real-time servers., defaults to None
        :type entries: Optional[List[RealtimeServer]], optional
        """
        super().__init__(**kwargs)
        self.chunk_size = chunk_size
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiLlmEndpointParamsIbmTypeField(str, Enum):
    IBM_PARAMS = 'ibm_params'


class AiLlmEndpointParamsIbm(BaseObject):
    _discriminator = 'type', {'ibm_params'}

    def __init__(
        self,
        *,
        type: AiLlmEndpointParamsIbmTypeField = AiLlmEndpointParamsIbmTypeField.IBM_PARAMS,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[float] = None,
        **kwargs
    ):
        """
                :param type: The type of the AI LLM endpoint params object for IBM.
        This parameter is **required**., defaults to AiLlmEndpointParamsIbmTypeField.IBM_PARAMS
                :type type: AiLlmEndpointParamsIbmTypeField, optional
                :param temperature: What sampling temperature to use, between 0 and 1. Higher values like 0.8 will make the output more random,
        while lower values like 0.2 will make it more focused and deterministic.
        We generally recommend altering this or `top_p` but not both., defaults to None
                :type temperature: Optional[float], optional
                :param top_p: An alternative to sampling with temperature, called nucleus sampling, where the model considers the results
        of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability
        mass are considered. We generally recommend altering this or temperature but not both., defaults to None
                :type top_p: Optional[float], optional
                :param top_k: `Top-K` changes how the model selects tokens for output. A low `top-K` means the next selected token is
        the most probable among all tokens in the model's vocabulary (also called greedy decoding),
        while a high `top-K` means that the next token is selected from among the three most probable tokens by using temperature., defaults to None
                :type top_k: Optional[float], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.temperature = temperature
        self.top_p = top_p
        self.top_k = top_k



from typing import Optional

from box_sdk_gen.schemas.file_base import FileBaseTypeField

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.box.errors import BoxSDKError


class FileConflict(FileMini):
    def __init__(
        self,
        id: str,
        *,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        sha_1: Optional[str] = None,
        file_version: Optional[FileVersionMini] = None,
        etag: Optional[str] = None,
        type: FileBaseTypeField = FileBaseTypeField.FILE,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
                :type id: str
                :param name: The name of the file., defaults to None
                :type name: Optional[str], optional
                :param sha_1: The SHA1 hash of the file. This can be used to compare the contents
        of a file on Box with a local file., defaults to None
                :type sha_1: Optional[str], optional
                :param etag: The HTTP `etag` of this file. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the file if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `file`., defaults to FileBaseTypeField.FILE
                :type type: FileBaseTypeField, optional
        """
        super().__init__(
            id=id,
            sequence_id=sequence_id,
            name=name,
            sha_1=sha_1,
            file_version=file_version,
            etag=etag,
            type=type,
            **kwargs
        )



from typing import Optional

from typing import Union

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.event import Event

from box_sdk_gen.box.errors import BoxSDKError


class Events(BaseObject):
    def __init__(
        self,
        *,
        chunk_size: Optional[int] = None,
        next_stream_position: Optional[Union[str, int]] = None,
        entries: Optional[List[Event]] = None,
        **kwargs
    ):
        """
                :param chunk_size: The number of events returned in this response., defaults to None
                :type chunk_size: Optional[int], optional
                :param next_stream_position: The stream position of the start of the next page (chunk)
        of events., defaults to None
                :type next_stream_position: Optional[Union[str, int]], optional
                :param entries: A list of events., defaults to None
                :type entries: Optional[List[Event]], optional
        """
        super().__init__(**kwargs)
        self.chunk_size = chunk_size
        self.next_stream_position = next_stream_position
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiLlmEndpointParamsGoogleTypeField(str, Enum):
    GOOGLE_PARAMS = 'google_params'


class AiLlmEndpointParamsGoogle(BaseObject):
    _discriminator = 'type', {'google_params'}

    def __init__(
        self,
        *,
        type: AiLlmEndpointParamsGoogleTypeField = AiLlmEndpointParamsGoogleTypeField.GOOGLE_PARAMS,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[float] = None,
        **kwargs
    ):
        """
                :param type: The type of the AI LLM endpoint params object for Google.
        This parameter is **required**., defaults to AiLlmEndpointParamsGoogleTypeField.GOOGLE_PARAMS
                :type type: AiLlmEndpointParamsGoogleTypeField, optional
                :param temperature: The temperature is used for sampling during response generation, which occurs when `top-P` and `top-K` are applied. Temperature controls the degree of randomness in the token selection., defaults to None
                :type temperature: Optional[float], optional
                :param top_p: `Top-P` changes how the model selects tokens for output. Tokens are selected from the most (see `top-K`) to least probable until the sum of their probabilities equals the `top-P` value., defaults to None
                :type top_p: Optional[float], optional
                :param top_k: `Top-K` changes how the model selects tokens for output. A low `top-K` means the next selected token is
        the most probable among all tokens in the model's vocabulary (also called greedy decoding),
        while a high `top-K` means that the next token is selected from among the three most probable tokens by using temperature., defaults to None
                :type top_k: Optional[float], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.temperature = temperature
        self.top_p = top_p
        self.top_k = top_k



import io

import time
from collections import OrderedDict
from dataclasses import dataclass
from typing import Optional, Dict, Union, Tuple
from sys import version_info as py_version

import requests
from requests import RequestException, Session, Response
from requests_toolbelt import MultipartEncoder

from ..internal.logging import DataSanitizer
from .retries import BoxRetryStrategy
from ..networking.fetch_options import FetchOptions
from ..networking.fetch_response import FetchResponse
from ..box.errors import BoxAPIError, BoxSDKError, RequestInfo, ResponseInfo
from ..internal.utils import ByteStream, ResponseByteStream
from ..networking.network_client import NetworkClient
from ..networking.timeout_config import TimeoutConfig
from ..serialization.json import (
    sd_to_json,
    sd_to_url_params,
    json_to_serialized_data,
)
from ..networking.version import __version__

SDK_VERSION = __version__
USER_AGENT_HEADER = f'box-python-generated-sdk-{SDK_VERSION}'
X_BOX_UA_HEADER = (
    f'agent=box-python-generated-sdk/{SDK_VERSION}; '
    f'env=python/{py_version.major}.{py_version.minor}.{py_version.micro}'
)


@dataclass
class APIRequest:
    method: str
    url: str
    headers: Dict[str, str]
    params: Dict[str, str]
    data: Optional[Union[str, ByteStream, MultipartEncoder]]
    allow_redirects: bool = True
    timeout: Optional[Tuple[Optional[float], Optional[float]]] = None


@dataclass
class APIResponse:
    network_response: Optional[Response] = None
    reauthentication_needed: Optional[bool] = False
    raised_exception: Optional[Exception] = None

    def get_header(
        self, header_name: str, default_value: Optional[str] = None
    ) -> Optional[str]:
        try:
            return self.network_response.headers[header_name]
        except (ValueError, KeyError, AttributeError):
            return default_value


class BoxNetworkClient(NetworkClient):
    def __init__(self, requests_session: Optional[Session] = None):
        super().__init__()
        self.requests_session = requests_session or requests.Session()

    def fetch(self, options: 'FetchOptions') -> FetchResponse:
        retry_strategy = (
            options.network_session.retry_strategy
            if options.network_session
            else BoxRetryStrategy()
        )
        data_sanitizer = (
            options.network_session.data_sanitizer
            if options.network_session
            else DataSanitizer()
        )

        attempt_nr = 1
        number_of_retries_on_exception = 0
        response = APIResponse()

        options_stream_position = self._get_options_stream_position(options)
        multipart_streams_positions = self._get_multipart_stream_positions(options)

        while True:
            request: APIRequest = self._prepare_request(
                options=options, reauthenticate=response.reauthentication_needed
            )
            response: APIResponse = self._make_request(request=request)
            if response.network_response is not None:
                attempt_for_retry = attempt_nr
                network_response = response.network_response

                if options.response_format == 'binary':
                    fetch_response = FetchResponse(
                        url=network_response.url,
                        status=network_response.status_code,
                        headers=dict(response.network_response.headers),
                        content=ResponseByteStream(
                            response.network_response.iter_content(chunk_size=1024)
                        ),
                    )
                else:
                    fetch_response = FetchResponse(
                        url=network_response.url,
                        status=network_response.status_code,
                        headers=dict(response.network_response.headers),
                        data=(self._read_json_body(network_response.text)),
                        content=io.BytesIO(network_response.content),
                    )
            else:
                number_of_retries_on_exception += 1
                attempt_for_retry = number_of_retries_on_exception
                fetch_response = FetchResponse(status=0, headers={})

            attempt_nr += 1
            should_retry = retry_strategy.should_retry(
                fetch_options=options,
                fetch_response=fetch_response,
                attempt_number=attempt_for_retry,
            )

            if should_retry:
                self._reset_options_stream(
                    options, options_stream_position, response.raised_exception
                )
                self._reset_multipart_streams(
                    options, multipart_streams_positions, response.raised_exception
                )
                time.sleep(
                    retry_strategy.retry_after(
                        fetch_options=options,
                        fetch_response=fetch_response,
                        attempt_number=attempt_for_retry,
                    )
                )
                continue

            if 200 <= fetch_response.status < 400:
                return fetch_response
            break
        self._raise_on_unsuccessful_request(
            request=request, response=response, data_sanitizer=data_sanitizer
        )

    def _prepare_request(
        self, options: 'FetchOptions', reauthenticate: bool = False
    ) -> APIRequest:
        headers = self._prepare_headers(options, reauthenticate)
        params = options.params or {}
        data = self._prepare_body(
            options.content_type, options.file_stream or options.data
        )
        allow_redirects = options.follow_redirects
        timeout = self._get_request_timeout(options)

        if options.content_type:
            if options.content_type == 'multipart/form-data':
                fields = OrderedDict()
                for part in options.multipart_data:
                    if part.data:
                        fields[part.part_name] = sd_to_json(part.data)
                    else:
                        fields[part.part_name] = (
                            part.file_name or '',
                            part.file_stream,
                            part.content_type,
                        )

                multipart_stream = MultipartEncoder(fields)
                data = multipart_stream
                headers['Content-Type'] = multipart_stream.content_type
            else:
                headers['Content-Type'] = options.content_type

        return APIRequest(
            method=options.method,
            url=options.url,
            headers=headers,
            params=params,
            data=data,
            allow_redirects=allow_redirects,
            timeout=timeout,
        )

    @staticmethod
    def _get_request_timeout(
        options: 'FetchOptions',
    ) -> Optional[Tuple[Optional[float], Optional[float]]]:
        """
        Derive requests timeout tuple (connect, read) in seconds.

        Uses `options.network_session.timeout_config` when present.
        The timeout config values are expected to be in milliseconds.
        """
        network_session = options.network_session
        timeout_config = network_session.timeout_config if network_session else None
        if timeout_config is None:
            return None

        connection_timeout_ms, read_timeout_ms = (
            timeout_config.connection_timeout_ms,
            timeout_config.read_timeout_ms,
        )

        if connection_timeout_ms is None and read_timeout_ms is None:
            return None

        connection_timeout_sec = (
            connection_timeout_ms / 1000.0
            if connection_timeout_ms is not None
            else None
        )
        read_timeout_sec = (
            read_timeout_ms / 1000.0 if read_timeout_ms is not None else None
        )

        return (connection_timeout_sec, read_timeout_sec)

    @staticmethod
    def _prepare_headers(
        options: 'FetchOptions', reauthenticate: bool = False
    ) -> Dict[str, str]:
        headers = {}
        if options.network_session:
            headers.update(options.network_session.additional_headers)
        if options.headers:
            headers.update(options.headers)
        if options.auth:
            if reauthenticate:
                options.auth.refresh_token(network_session=options.network_session)
            headers['Authorization'] = options.auth.retrieve_authorization_header(
                network_session=options.network_session
            )

        headers['User-Agent'] = USER_AGENT_HEADER
        headers['X-Box-UA'] = X_BOX_UA_HEADER
        return headers

    @staticmethod
    def _prepare_body(
        content_type: str, data: Union[dict, ByteStream]
    ) -> Optional[Union[str, ByteStream]]:
        if (
            content_type == 'application/json'
            or content_type == 'application/json-patch+json'
        ):
            return sd_to_json(data) if data else None
        if content_type == 'application/x-www-form-urlencoded':
            return sd_to_url_params(data)
        if (
            content_type == 'multipart/form-data'
            or content_type == 'application/octet-stream'
        ):
            return data
        raise ValueError(f'Unsupported content type: {content_type}')

    def _make_request(self, request: APIRequest) -> APIResponse:
        raised_exception = None
        reauthentication_needed = False
        timeout = request.timeout
        try:
            network_response = self.requests_session.request(
                method=request.method,
                url=request.url,
                headers=request.headers,
                data=request.data,
                params=request.params,
                allow_redirects=request.allow_redirects,
                stream=True,
                timeout=timeout,
            )
        except RequestException as request_exc:
            raised_exception = request_exc
            network_response = None

            if 'EOF occurred in violation of protocol' in str(request_exc):
                reauthentication_needed = True

        return APIResponse(
            network_response=network_response,
            reauthentication_needed=reauthentication_needed,
            raised_exception=raised_exception,
        )

    @staticmethod
    def _raise_on_unsuccessful_request(
        request: APIRequest, response: APIResponse, data_sanitizer: DataSanitizer
    ) -> None:
        if response.raised_exception:
            raise BoxSDKError(
                message=str(response.raised_exception), error=response.raised_exception
            )

        network_response = response.network_response
        response_json = BoxNetworkClient._read_json_body(network_response.text)

        raise BoxAPIError(
            message=f'{network_response.status_code} {response_json.get("message", "")}; Request ID: {response_json.get("request_id", "")}',
            request_info=RequestInfo(
                method=request.method,
                url=request.url,
                query_params=request.params,
                headers=request.headers,
                body=request.data,
            ),
            response_info=ResponseInfo(
                status_code=network_response.status_code,
                headers=dict(network_response.headers),
                body=response_json,
                raw_body=network_response.text,
                code=response_json.get("code", None),
                context_info=response_json.get("context_info", {}),
                request_id=response_json.get("request_id", None),
                help_url=response_json.get("help_url", None),
            ),
            data_sanitizer=data_sanitizer,
        )

    @staticmethod
    def _get_multipart_stream_positions(options: 'FetchOptions') -> dict:
        multipart_streams_positions = {}
        if options.multipart_data:
            for part in options.multipart_data:
                if part.file_stream and part.file_stream.seekable():
                    multipart_streams_positions[part.part_name] = (
                        part.file_stream.tell()
                    )
        return multipart_streams_positions

    @staticmethod
    def _get_options_stream_position(options: 'FetchOptions') -> int:
        filestream_position = 0
        if options.file_stream and options.file_stream.seekable():
            filestream_position = options.file_stream.tell()
        return filestream_position

    @staticmethod
    def _validate_seekable(stream: ByteStream, raised_exception: Optional[Exception]):
        if not stream.seekable():
            raise BoxSDKError(
                message='Request with non-seekable stream cannot be retried',
                error=raised_exception,
            )

    @staticmethod
    def _read_json_body(response_body: str) -> dict:
        if not response_body:
            return {}
        try:
            return json_to_serialized_data(response_body)
        except (ValueError, TypeError):
            return {}

    def _reset_stream(
        self,
        stream: ByteStream,
        original_position: int,
        raised_exception: Optional[Exception],
    ):
        self._validate_seekable(stream, raised_exception)
        stream.seek(original_position)

    def _reset_options_stream(
        self,
        options: 'FetchOptions',
        filestream_position: int,
        raised_exception: Optional[Exception],
    ):
        if options.file_stream:
            self._reset_stream(
                options.file_stream, filestream_position, raised_exception
            )

    def _reset_multipart_streams(
        self,
        options: 'FetchOptions',
        multipart_streams_positions: dict,
        raised_exception: Optional[Exception],
    ):
        if not options.multipart_data:
            return

        for part in options.multipart_data:
            if not part.file_stream:
                continue

            position = multipart_streams_positions.get(part.part_name)
            # we didn't get position before sending request hence the stream must be non-seekable
            if position is None:
                raise BoxSDKError(
                    message='Request with non-seekable stream cannot be retried',
                    error=raised_exception,
                )

            self._reset_stream(
                part.file_stream,
                multipart_streams_positions[part.part_name],
                raised_exception,
            )



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_base import UserBaseTypeField

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class UserStatusField(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'
    CANNOT_DELETE_EDIT = 'cannot_delete_edit'
    CANNOT_DELETE_EDIT_UPLOAD = 'cannot_delete_edit_upload'


class UserNotificationEmailField(BaseObject):
    def __init__(
        self,
        *,
        email: Optional[str] = None,
        is_confirmed: Optional[bool] = None,
        **kwargs
    ):
        """
        :param email: The email address to send the notifications to., defaults to None
        :type email: Optional[str], optional
        :param is_confirmed: Specifies if this email address has been confirmed., defaults to None
        :type is_confirmed: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.email = email
        self.is_confirmed = is_confirmed


class User(UserMini):
    def __init__(
        self,
        id: str,
        *,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        language: Optional[str] = None,
        timezone: Optional[str] = None,
        space_amount: Optional[int] = None,
        space_used: Optional[int] = None,
        max_upload_size: Optional[int] = None,
        status: Optional[UserStatusField] = None,
        job_title: Optional[str] = None,
        phone: Optional[str] = None,
        address: Optional[str] = None,
        avatar_url: Optional[str] = None,
        notification_email: Optional[UserNotificationEmailField] = None,
        name: Optional[str] = None,
        login: Optional[str] = None,
        type: UserBaseTypeField = UserBaseTypeField.USER,
        **kwargs
    ):
        """
                :param id: The unique identifier for this user.
                :type id: str
                :param created_at: When the user object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the user object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param language: The language of the user, formatted in modified version of the
        [ISO 639-1](https://developer.box.com/guides/api-calls/language-codes) format., defaults to None
                :type language: Optional[str], optional
                :param timezone: The user's timezone., defaults to None
                :type timezone: Optional[str], optional
                :param space_amount: The user’s total available space amount in bytes., defaults to None
                :type space_amount: Optional[int], optional
                :param space_used: The amount of space in use by the user., defaults to None
                :type space_used: Optional[int], optional
                :param max_upload_size: The maximum individual file size in bytes the user can have., defaults to None
                :type max_upload_size: Optional[int], optional
                :param status: The user's account status., defaults to None
                :type status: Optional[UserStatusField], optional
                :param job_title: The user’s job title., defaults to None
                :type job_title: Optional[str], optional
                :param phone: The user’s phone number., defaults to None
                :type phone: Optional[str], optional
                :param address: The user’s address., defaults to None
                :type address: Optional[str], optional
                :param avatar_url: URL of the user’s avatar image., defaults to None
                :type avatar_url: Optional[str], optional
                :param notification_email: An alternate notification email address to which email
        notifications are sent. When it's confirmed, this will be
        the email address to which notifications are sent instead of
        to the primary email address., defaults to None
                :type notification_email: Optional[UserNotificationEmailField], optional
                :param name: The display name of this user., defaults to None
                :type name: Optional[str], optional
                :param login: The primary email address of this user., defaults to None
                :type login: Optional[str], optional
                :param type: The value will always be `user`., defaults to UserBaseTypeField.USER
                :type type: UserBaseTypeField, optional
        """
        super().__init__(id=id, name=name, login=login, type=type, **kwargs)
        self.created_at = created_at
        self.modified_at = modified_at
        self.language = language
        self.timezone = timezone
        self.space_amount = space_amount
        self.space_used = space_used
        self.max_upload_size = max_upload_size
        self.status = status
        self.job_title = job_title
        self.phone = phone
        self.address = address
        self.avatar_url = avatar_url
        self.notification_email = notification_email



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.v2025_r0.group_base_v2025_r0 import GroupBaseV2025R0TypeField

from box_sdk_gen.schemas.v2025_r0.group_base_v2025_r0 import GroupBaseV2025R0

from box_sdk_gen.box.errors import BoxSDKError


class GroupMiniV2025R0GroupTypeField(str, Enum):
    MANAGED_GROUP = 'managed_group'
    ALL_USERS_GROUP = 'all_users_group'


class GroupMiniV2025R0(GroupBaseV2025R0):
    def __init__(
        self,
        id: str,
        *,
        name: Optional[str] = None,
        group_type: Optional[GroupMiniV2025R0GroupTypeField] = None,
        type: GroupBaseV2025R0TypeField = GroupBaseV2025R0TypeField.GROUP,
        **kwargs
    ):
        """
        :param id: The unique identifier for this object.
        :type id: str
        :param name: The name of the group., defaults to None
        :type name: Optional[str], optional
        :param group_type: The type of the group., defaults to None
        :type group_type: Optional[GroupMiniV2025R0GroupTypeField], optional
        :param type: The value will always be `group`., defaults to GroupBaseV2025R0TypeField.GROUP
        :type type: GroupBaseV2025R0TypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.name = name
        self.group_type = group_type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.retention_policy_mini import RetentionPolicyMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class RetentionPolicyAssignmentTypeField(str, Enum):
    RETENTION_POLICY_ASSIGNMENT = 'retention_policy_assignment'


class RetentionPolicyAssignmentAssignedToTypeField(str, Enum):
    FOLDER = 'folder'
    ENTERPRISE = 'enterprise'
    METADATA_TEMPLATE = 'metadata_template'


class RetentionPolicyAssignmentAssignedToField(BaseObject):
    _discriminator = 'type', {'folder', 'enterprise', 'metadata_template'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[RetentionPolicyAssignmentAssignedToTypeField] = None,
        **kwargs
    ):
        """
                :param id: The ID of the folder, enterprise, or metadata template
        the policy is assigned to.
        Set to null or omit when type is set to enterprise., defaults to None
                :type id: Optional[str], optional
                :param type: The type of resource the policy is assigned to., defaults to None
                :type type: Optional[RetentionPolicyAssignmentAssignedToTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class RetentionPolicyAssignmentFilterFieldsField(BaseObject):
    def __init__(
        self, *, field: Optional[str] = None, value: Optional[str] = None, **kwargs
    ):
        """
                :param field: The metadata attribute key id., defaults to None
                :type field: Optional[str], optional
                :param value: The metadata attribute field id. For value, only
        enum and multiselect types are supported., defaults to None
                :type value: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.field = field
        self.value = value


class RetentionPolicyAssignment(BaseObject):
    _discriminator = 'type', {'retention_policy_assignment'}

    def __init__(
        self,
        id: str,
        *,
        type: RetentionPolicyAssignmentTypeField = RetentionPolicyAssignmentTypeField.RETENTION_POLICY_ASSIGNMENT,
        retention_policy: Optional[RetentionPolicyMini] = None,
        assigned_to: Optional[RetentionPolicyAssignmentAssignedToField] = None,
        filter_fields: Optional[
            List[RetentionPolicyAssignmentFilterFieldsField]
        ] = None,
        assigned_by: Optional[UserMini] = None,
        assigned_at: Optional[DateTime] = None,
        start_date_field: Optional[str] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for a retention policy assignment.
                :type id: str
                :param type: The value will always be `retention_policy_assignment`., defaults to RetentionPolicyAssignmentTypeField.RETENTION_POLICY_ASSIGNMENT
                :type type: RetentionPolicyAssignmentTypeField, optional
                :param assigned_to: The `type` and `id` of the content that is under
        retention. The `type` can either be `folder`
        `enterprise`, or `metadata_template`., defaults to None
                :type assigned_to: Optional[RetentionPolicyAssignmentAssignedToField], optional
                :param filter_fields: An array of field objects. Values are only returned if the `assigned_to`
        type is `metadata_template`. Otherwise, the array is blank., defaults to None
                :type filter_fields: Optional[List[RetentionPolicyAssignmentFilterFieldsField]], optional
                :param assigned_at: When the retention policy assignment object was
        created., defaults to None
                :type assigned_at: Optional[DateTime], optional
                :param start_date_field: The date the retention policy assignment begins.
        If the `assigned_to` type is `metadata_template`,
        this field can be a date field's metadata attribute key id., defaults to None
                :type start_date_field: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.retention_policy = retention_policy
        self.assigned_to = assigned_to
        self.filter_fields = filter_fields
        self.assigned_by = assigned_by
        self.assigned_at = assigned_at
        self.start_date_field = start_date_field



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.folder_reference_v2025_r0 import (
    FolderReferenceV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.weblink_reference_v2025_r0 import (
    WeblinkReferenceV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_item_reference_v2025_r0 import (
    HubItemReferenceV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class HubItemOperationResultV2025R0(BaseObject):
    def __init__(
        self,
        *,
        action: Optional[str] = None,
        item: Optional[HubItemReferenceV2025R0] = None,
        status: Optional[int] = None,
        error: Optional[str] = None,
        **kwargs
    ):
        """
        :param action: The action performed on the item., defaults to None
        :type action: Optional[str], optional
        :param status: The HTTP status code of the operation., defaults to None
        :type status: Optional[int], optional
        :param error: Error message if the operation failed., defaults to None
        :type error: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.action = action
        self.item = item
        self.status = status
        self.error = error



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class TermsOfServiceBaseV2025R0TypeField(str, Enum):
    TERMS_OF_SERVICE = 'terms_of_service'


class TermsOfServiceBaseV2025R0(BaseObject):
    _discriminator = 'type', {'terms_of_service'}

    def __init__(
        self,
        id: str,
        *,
        type: TermsOfServiceBaseV2025R0TypeField = TermsOfServiceBaseV2025R0TypeField.TERMS_OF_SERVICE,
        **kwargs
    ):
        """
        :param id: The unique identifier for this terms of service.
        :type id: str
        :param type: The value will always be `terms_of_service`., defaults to TermsOfServiceBaseV2025R0TypeField.TERMS_OF_SERVICE
        :type type: TermsOfServiceBaseV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from typing import Optional

from typing import List

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenGrantTypeField

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenSubjectTokenTypeField

from box_sdk_gen.schemas.access_token import AccessToken

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenBoxSubjectTypeField

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.box.token_storage import TokenStorage

from box_sdk_gen.box.token_storage import InMemoryTokenStorage

from box_sdk_gen.managers.authorization import AuthorizationManager

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2Token

from box_sdk_gen.schemas.post_o_auth_2_revoke import PostOAuth2Revoke


class CCGConfig:
    def __init__(
        self,
        client_id: str,
        client_secret: str,
        *,
        enterprise_id: Optional[str] = None,
        user_id: Optional[str] = None,
        token_storage: TokenStorage = None
    ):
        """
        :param client_id: Box API key used for identifying the application the user is authenticating with
        :type client_id: str
        :param client_secret: Box API secret used for making auth requests.
        :type client_secret: str
        :param enterprise_id: The ID of the Box Developer Edition enterprise., defaults to None
        :type enterprise_id: Optional[str], optional
        :param user_id: The user id to authenticate. This value is not required. But if it is provided, then the user will be auto-authenticated at the time of the first API call., defaults to None
        :type user_id: Optional[str], optional
        :param token_storage: Object responsible for storing token. If no custom implementation provided,the token will be stored in memory., defaults to None
        :type token_storage: TokenStorage, optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        self.client_id = client_id
        self.client_secret = client_secret
        self.enterprise_id = enterprise_id
        self.user_id = user_id
        self.token_storage = token_storage


class BoxCCGAuth(Authentication):
    def __init__(self, config: CCGConfig, **kwargs):
        """
        :param config: Configuration object of Client Credentials Grant auth.
        :type config: CCGConfig
        """
        super().__init__(**kwargs)
        self.config = config
        self.token_storage = self.config.token_storage
        self.subject_id = (
            self.config.user_id
            if not self.config.user_id == None
            else self.config.enterprise_id
        )
        self.subject_type = (
            PostOAuth2TokenBoxSubjectTypeField.USER
            if not self.config.user_id == None
            else PostOAuth2TokenBoxSubjectTypeField.ENTERPRISE
        )

    def refresh_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Get a new access token using CCG auth
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.CLIENT_CREDENTIALS,
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            box_subject_type=self.subject_type,
            box_subject_id=self.subject_id,
        )
        self.token_storage.store(token)
        return token

    def retrieve_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Return a current token or get a new one when not available.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        old_token: Optional[AccessToken] = self.token_storage.get()
        if old_token == None:
            new_token: AccessToken = self.refresh_token(network_session=network_session)
            return new_token
        return old_token

    def retrieve_authorization_header(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> str:
        token: AccessToken = self.retrieve_token(network_session=network_session)
        return ''.join(['Bearer ', token.access_token])

    def with_user_subject(
        self, user_id: str, *, token_storage: TokenStorage = None
    ) -> 'BoxCCGAuth':
        """
        Create a new BoxCCGAuth instance that uses the provided user ID as the subject ID.

        May be one of this application's created App User. Depending on the configured User Access Level, may also be any other App User or Managed User in the enterprise.


        <https://developer.box.com/en/guides/applications/>


        <https://developer.box.com/en/guides/authentication/select/>

        :param user_id: The id of the user to authenticate
        :type user_id: str
        :param token_storage: Object responsible for storing token in newly created BoxCCGAuth. If no custom implementation provided, the token will be stored in memory., defaults to None
        :type token_storage: TokenStorage, optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        new_config: CCGConfig = CCGConfig(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            enterprise_id=self.config.enterprise_id,
            user_id=user_id,
            token_storage=token_storage,
        )
        return BoxCCGAuth(config=new_config)

    def with_enterprise_subject(
        self, enterprise_id: str, *, token_storage: TokenStorage = None
    ) -> 'BoxCCGAuth':
        """
        Create a new BoxCCGAuth instance that uses the provided enterprise ID as the subject ID.
        :param enterprise_id: The id of the enterprise to authenticate
        :type enterprise_id: str
        :param token_storage: Object responsible for storing token in newly created BoxCCGAuth. If no custom implementation provided, the token will be stored in memory., defaults to None
        :type token_storage: TokenStorage, optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        new_config: CCGConfig = CCGConfig(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            enterprise_id=enterprise_id,
            user_id=None,
            token_storage=token_storage,
        )
        return BoxCCGAuth(config=new_config)

    def downscope_token(
        self,
        scopes: List[str],
        *,
        resource: Optional[str] = None,
        shared_link: Optional[str] = None,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Downscope access token to the provided scopes. Returning a new access token with the provided scopes, with the original access token unchanged.
        :param scopes: The scope(s) to apply to the resulting token.
        :type scopes: List[str]
        :param resource: The file or folder to get a downscoped token for. If None and shared_link None, the resulting token will not be scoped down to just a single item. The resource should be a full URL to an item, e.g. https://api.box.com/2.0/files/123456., defaults to None
        :type resource: Optional[str], optional
        :param shared_link: The shared link to get a downscoped token for. If None and item None, the resulting token will not be scoped down to just a single item., defaults to None
        :type shared_link: Optional[str], optional
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.retrieve_token(
            network_session=network_session
        )
        if token == None:
            raise BoxSDKError(
                message='No access token is available. Make an API call to retrieve a token before calling this method.'
            )
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        downscoped_token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.URN_IETF_PARAMS_OAUTH_GRANT_TYPE_TOKEN_EXCHANGE,
            subject_token=token.access_token,
            subject_token_type=PostOAuth2TokenSubjectTokenTypeField.URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN,
            resource=resource,
            scope=' '.join(scopes),
            box_shared_link=shared_link,
        )
        return downscoped_token

    def revoke_token(self, *, network_session: Optional[NetworkSession] = None) -> None:
        """
        Revoke the current access token and remove it from token storage.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        old_token: Optional[AccessToken] = self.token_storage.get()
        if old_token == None:
            return None
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        auth_manager.revoke_access_token(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            token=old_token.access_token,
        )
        self.token_storage.clear()
        return None



from enum import Enum

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.file_versions import FileVersions

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.file_version_full import FileVersionFull

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class PromoteFileVersionType(str, Enum):
    FILE_VERSION = 'file_version'


class FileVersionsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_versions(
        self,
        file_id: str,
        *,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersions:
        """
                Retrieve a list of the past versions for a file.

                Versions are only tracked by Box users with premium accounts. To fetch the ID


                of the current version of a file, use the `GET /file/:id` API.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'limit': to_string(limit),
                'offset': to_string(offset),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/versions',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersions)

    def get_file_version_by_id(
        self,
        file_id: str,
        file_version_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersionFull:
        """
                Retrieve a specific version of a file.

                Versions are only tracked for Box users with premium accounts.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param file_version_id: The ID of the file version.
        Example: "1234"
                :type file_version_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/versions/',
                        to_string(file_version_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersionFull)

    def delete_file_version_by_id(
        self,
        file_id: str,
        file_version_id: str,
        *,
        if_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Move a file version to the trash.

                Versions are only tracked for Box users with premium accounts.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param file_version_id: The ID of the file version.
        Example: "1234"
                :type file_version_id: str
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'if-match': to_string(if_match), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/versions/',
                        to_string(file_version_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def update_file_version_by_id(
        self,
        file_id: str,
        file_version_id: str,
        *,
        trashed_at: Union[Optional[str], NullValue] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersionFull:
        """
                Restores a specific version of a file after it was deleted.

                Don't use this endpoint to restore Box Notes,


                as it works with file formats such as PDF, DOC,


                PPTX or similar.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param file_version_id: The ID of the file version.
        Example: "1234"
                :type file_version_id: str
                :param trashed_at: Set this to `null` to clear
        the date and restore the file., defaults to None
                :type trashed_at: Union[Optional[str], NullValue], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'trashed_at': trashed_at}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/versions/',
                        to_string(file_version_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersionFull)

    def promote_file_version(
        self,
        file_id: str,
        *,
        id: Optional[str] = None,
        type: Optional[PromoteFileVersionType] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileVersionFull:
        """
                Promote a specific version of a file.

                If previous versions exist, this method can be used to


                promote one of the older versions to the top of the version history.


                This creates a new copy of the old version and puts it at the


                top of the versions history. The file will have the exact same contents


                as the older version, with the same hash digest, `etag`, and


                name as the original.


                Other properties such as comments do not get updated to their


                former values.


                Don't use this endpoint to restore Box Notes,


                as it works with file formats such as PDF, DOC,


                PPTX or similar.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param id: The file version ID., defaults to None
                :type id: Optional[str], optional
                :param type: The type to promote., defaults to None
                :type type: Optional[PromoteFileVersionType], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'id': id, 'type': type}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/versions/current',
                    ]
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileVersionFull)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTemplateTypeField(str, Enum):
    METADATA_TEMPLATE = 'metadata_template'


class MetadataTemplateFieldsTypeField(str, Enum):
    STRING = 'string'
    FLOAT = 'float'
    DATE = 'date'
    ENUM = 'enum'
    MULTISELECT = 'multiSelect'
    INTEGER = 'integer'
    TAXONOMY = 'taxonomy'


class MetadataTemplateFieldsOptionsField(BaseObject):
    def __init__(self, key: str, *, id: Optional[str] = None, **kwargs):
        """
                :param key: The text value of the option. This represents both the display name of the
        option and the internal key used when updating templates.
                :type key: str
                :param id: The internal unique identifier of the option., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.id = id


class MetadataTemplateFieldsField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {
        'string',
        'float',
        'date',
        'enum',
        'multiSelect',
        'integer',
        'taxonomy',
    }

    def __init__(
        self,
        type: MetadataTemplateFieldsTypeField,
        key: str,
        display_name: str,
        *,
        description: Optional[str] = None,
        hidden: Optional[bool] = None,
        options: Optional[List[MetadataTemplateFieldsOptionsField]] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of field. The basic fields are a `string` field for text, a
        `float` field for numbers, and a `date` fields to present the user with a
        date-time picker.

        Additionally, metadata templates support an `enum` field for a basic list
        of items, and ` multiSelect` field for a similar list of items where the
        user can select more than one value.

        **Note**: The `integer` value is deprecated.
        It is still present in the response,
        but cannot be used in the POST request.
                :type type: MetadataTemplateFieldsTypeField
                :param key: A unique identifier for the field. The identifier must
        be unique within the template to which it belongs.
                :type key: str
                :param display_name: The display name of the field as it is shown to the user in the web and
        mobile apps.
                :type display_name: str
                :param description: A description of the field. This is not shown to the user., defaults to None
                :type description: Optional[str], optional
                :param hidden: Whether this field is hidden in the UI for the user and can only be set
        through the API instead., defaults to None
                :type hidden: Optional[bool], optional
                :param options: A list of options for this field. This is used in combination
        with the `enum` and `multiSelect` field types., defaults to None
                :type options: Optional[List[MetadataTemplateFieldsOptionsField]], optional
                :param id: The unique ID of the metadata template field., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.key = key
        self.display_name = display_name
        self.description = description
        self.hidden = hidden
        self.options = options
        self.id = id


class MetadataTemplate(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'template_key': 'templateKey',
        'display_name': 'displayName',
        'copy_instance_on_item_copy': 'copyInstanceOnItemCopy',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'templateKey': 'template_key',
        'displayName': 'display_name',
        'copyInstanceOnItemCopy': 'copy_instance_on_item_copy',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {'metadata_template'}

    def __init__(
        self,
        id: str,
        *,
        type: MetadataTemplateTypeField = MetadataTemplateTypeField.METADATA_TEMPLATE,
        scope: Optional[str] = None,
        template_key: Optional[str] = None,
        display_name: Optional[str] = None,
        hidden: Optional[bool] = None,
        fields: Optional[List[MetadataTemplateFieldsField]] = None,
        copy_instance_on_item_copy: Optional[bool] = None,
        **kwargs
    ):
        """
                :param id: The ID of the metadata template.
                :type id: str
                :param type: The value will always be `metadata_template`., defaults to MetadataTemplateTypeField.METADATA_TEMPLATE
                :type type: MetadataTemplateTypeField, optional
                :param scope: The scope of the metadata template can either be `global` or
        `enterprise_*`. The `global` scope is used for templates that are
        available to any Box enterprise. The `enterprise_*` scope represents
        templates that have been created within a specific enterprise, where `*`
        will be the ID of that enterprise., defaults to None
                :type scope: Optional[str], optional
                :param template_key: A unique identifier for the template. This identifier is unique across
        the `scope` of the enterprise to which the metadata template is being
        applied, yet is not necessarily unique across different enterprises., defaults to None
                :type template_key: Optional[str], optional
                :param display_name: The display name of the template. This can be seen in the Box web app
        and mobile apps., defaults to None
                :type display_name: Optional[str], optional
                :param hidden: Defines if this template is visible in the Box web app UI, or if
        it is purely intended for usage through the API., defaults to None
                :type hidden: Optional[bool], optional
                :param fields: An ordered list of template fields which are part of the template. Each
        field can be a regular text field, date field, number field, as well as a
        single or multi-select list., defaults to None
                :type fields: Optional[List[MetadataTemplateFieldsField]], optional
                :param copy_instance_on_item_copy: Whether or not to include the metadata when a file or folder is copied., defaults to None
                :type copy_instance_on_item_copy: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.scope = scope
        self.template_key = template_key
        self.display_name = display_name
        self.hidden = hidden
        self.fields = fields
        self.copy_instance_on_item_copy = copy_instance_on_item_copy
